\name{Dualtree}
\alias{dualtree}
\alias{idualtree}
\alias{dualtree2D}
\alias{idualtree2D}
\title{Dual-tree Complex Discrete Wavelet Transform}
\description{
  One- and two-dimensional dual-tree complex discrete wavelet transforms
  developed by Kingsbury and Selesnick \emph{et al.}
}
\usage{
dualtree(x, J, Faf, af)
idualtree(w, J, Fsf, sf)
dualtree2D(x, J, Faf, af)
idualtree2D(w, J, Fsf, sf)
}
\arguments{
  \item{x}{$N$-point vector or $M{\times}N$ matrix.}
  \item{w}{DWT coefficients.}
  \item{J}{number of stages.}
  \item{Faf}{analysis filters for the first stage.}
  \item{af}{analysis filters for the remaining stages.}
  \item{Fsf}{synthesis filters for the last stage.}
  \item{sf}{synthesis filters for the preceeding stages.}
}
\value{
  For the analysis of \code{x}, the output is
  \item{w}{DWT coefficients.  Each wavelet scale is a list containing
    the real and imaginary parts.  The final scale ($J+1$) contains the
    low-pass filter coefficients.}
  For the synthesis of \code{w}, the output is 
  \item{y}{output signal}
}
\details{
  In one dimension $N$ is divisible by $2^J$ and
  $N\ge2^{J-1}\cdot\mbox{length}(\mbox{\code{af}})$.

  In two dimensions, these two conditions must hold for both $M$ and
  $N$.
}
\references{
  WAVELET SOFTWARE AT POLYTECHNIC UNIVERSITY, BROOKLYN, NY
  \url{http://taco.poly.edu/WaveletSoftware/}
}
\seealso{
  \code{\link{FSfarras}}, \code{\link{farras}}, \code{\link{convolve}},
  \code{\link{cshift}}, \code{\link{afb}}, \code{\link{sfb}}.
}
\examples{
## EXAMPLE: dualtree
x = rnorm(512)
J = 4
Faf = FSfarras()$af
Fsf = FSfarras()$sf
af = dualfilt1()$af
sf = dualfilt1()$sf
w = dualtree(x, J, Faf, af)
y = idualtree(w, J, Fsf, sf)
err = x - y
max(abs(err))

## Example: dualtree2D
x = matrix(rnorm(64*64), 64, 64)
J = 3
Faf = FSfarras()$af
Fsf = FSfarras()$sf
af = dualfilt1()$af
sf = dualfilt1()$sf
w = dualtree2D(x, J, Faf, af)
y = idualtree2D(w, J, Fsf, sf)
err = x - y
max(abs(err))

## Display 2D wavelets of dualtree2D.m

J <- 4
L <- 3 * 2^(J+1)
N <- L / 2^J
Faf <- FSfarras()$af
Fsf <- FSfarras()$sf
af <- dualfilt1()$af
sf <- dualfilt1()$sf
x <- matrix(0, 2*L, 3*L)
w <- dualtree2D(x, J, Faf, af)
w[[J]][[1]][[1]][N/2, N/2+0*N] <- 1
w[[J]][[1]][[2]][N/2, N/2+1*N] <- 1
w[[J]][[1]][[3]][N/2, N/2+2*N] <- 1
w[[J]][[2]][[1]][N/2+N, N/2+0*N] <- 1
w[[J]][[2]][[2]][N/2+N, N/2+1*N] <- 1
w[[J]][[2]][[3]][N/2+N, N/2+2*N] <- 1
y <- idualtree2D(w, J, Fsf, sf)
image(t(y), col=grey(0:64/64), axes=FALSE)
}
\author{Matlab: S. Cai, K. Li and I. Selesnick; R port: B. Whitcher}
\keyword{ts}

\eof
\name{Farras}
\alias{farras}
\alias{FSfarras}
\title{Farras nearly symmetric filters}
\description{
  Farras nearly symmetric filters for orthogonal 2-channel perfect
  reconstruction filter bank and Farras filters organized for the
  dual-tree complex DWT.
}
\usage{
farras()
FSfarras()
}
\arguments{
  None.
}
\value{
  \item{af}{List ($i = 1,2$) - analysis filters for tree $i$}
  \item{sf}{List ($i = 1,2$) - synthesis filters for tree $i$}
}
\details{
}
\references{
  A. F. Abdelnour and I. W. Selesnick. "Nearly symmetric orthogonal
  wavelet bases", Proc. IEEE Int. Conf. Acoust., Speech, Signal
  Processing (ICASSP), May 2001.

  WAVELET SOFTWARE AT POLYTECHNIC UNIVERSITY, BROOKLYN, NY
  http://taco.poly.edu/WaveletSoftware/
}
\seealso{
  \code{\link{afb}}, \code{\link{dualtree}}, \code{\link{dualfilt1}}.
}
%\examples{}
\author{Matlab: S. Cai, K. Li and I. Selesnick; R port: B. Whitcher}
\keyword{ts}

\eof
\name{Selesnick}
\alias{cshift}
\alias{cshift2D}
\alias{pm}
\title{Miscellaneous Functions for Dual-tree Wavelet Software}
\description{
  
}
\usage{
cshift(x, m)
cshift2D(x, m)
pm(a, b)
}
\arguments{
  \item{x}{$N$-point vector}
  \item{m}{amount of shift}
  \item{a,b}{}
}
\value{
  \item{y}{vector $x$ will be shifed by $m$ samples to the left or
    matrix $x$ will be shifed by $m$ samples down.}
}
\details{
}
\references{
  WAVELET SOFTWARE AT POLYTECHNIC UNIVERSITY, BROOKLYN, NY
  http://taco.poly.edu/WaveletSoftware/
}
%\seealso{}
%\examples{}
\author{Matlab: S. Cai, K. Li and I. Selesnick; R port: B. Whitcher}
\keyword{ts}

\eof
\name{Thresholding}
\alias{Thresholding}
\alias{da.thresh}
\alias{hybrid.thresh}
\alias{manual.thresh}
\alias{sure.thresh}
\alias{universal.thresh}
\alias{universal.thresh.modwt}
\title{Wavelet Shrinkage via Thresholding}
\description{
  Perform wavelet shrinkage using data-analytic, hybrid SURE, manual,
  SURE, or universal thresholding.
}
\usage{
da.thresh(wc, alpha = .05, max.level = 4, verbose = FALSE, return.thresh = FALSE)
hybrid.thresh(wc, max.level = 4, verbose = FALSE, seed = 0)
manual.thresh(wc, max.level = 4, value, hard = TRUE)
sure.thresh(wc, max.level = 4, hard = TRUE)
universal.thresh(wc, max.level = 4, hard = TRUE)
universal.thresh.modwt(wc, max.level = 4, hard = TRUE)
}
\arguments{
  \item{wc}{wavelet coefficients}
  \item{alpha}{level of the hypothesis tests}
  \item{max.level}{maximum level of coefficients to be affected by threshold}
  \item{verbose}{if \code{verbose=TRUE} then information is printed to
    the screen} 
  \item{value}{threshold value (only utilized in \code{manual.thresh})}
  \item{hard}{Boolean value, if \code{hard=F} then soft thresholding is used}
  \item{seed}{sets random seed (only utilized in \code{hybrid.thresh})}
  \item{return.thresh}{if \code{return.thresh=TRUE} then the vector of
    threshold values is returned, otherwise the surviving wavelet
    coefficients are returned}
}
\value{
  The default output is a list structure, the same length as was input,
  containing only those wavelet coefficients surviving the threshold.
}
\details{
  An extensive amount of literature has been written on wavelet
  shrinkage.  The functions here represent the most basic approaches to
  the problem of nonparametric function estimation.  See the references
  for further information.
}
\references{
  Gencay, R., F. Selcuk and B. Whitcher (2001)
  \emph{An Introduction to Wavelets and Other Filtering Methods in
    Finance and Economics},
  Academic Press.

  Ogden, R. T. (1996)
  \emph{Essential Wavelets for Statistical Applications and Data
    Analysis},
  Birkhauser.

  Percival, D. B. and A. T. Walden (2000)
  \emph{Wavelet Methods for Time Series Analysis},
  Cambridge University Press.

  Vidakovic, B. (1999)
  \emph{Statistical Modeling by Wavelets},
  John Wiley \& Sons.
}
%\seealso{}
%\examples{}
\author{B. Whitcher (some code taken from R. Todd Ogden)}
\keyword{ts}

\eof
\name{acvs.andel8}
\alias{acvs.andel8}
\title{Autocovariance and Autocorrelation Sequences for a Seasonal
  Persistent Process}
\description{
  The autocovariance and autocorrelation sequences from the time series
  model in Figure 8 of Andel (1986).  They were obtained through numeric
  integration of the spectral density function.
}
\usage{data(acvs.andel8)
}
\format{
  A data frame with 4096 rows and three columns:
  \item{lag}{Lag}
  \item{acvs}{Autocovariance sequence}
  \item{acf}{Autocorrelation sequence}
}
\references{
  Andel, J. (1986)
  Long memory time series models,
  \emph{Kypernetika}, \bold{22}, No. 2, 105-123.
}
\keyword{datasets}

\eof
\name{ar1}
\alias{ar1}
\title{Simulated AR(1) Series}
\description{
  Simulated AR(1) series used in Gencay, Selcuk and Whitcher (2001).
}
\usage{data(ar1)
}
\format{A vector containing 200 observations.
}
%\source{}
\references{
  Gencay, R., F. Selcuk and B. Whitcher (2001)
  \emph{An Introduction to Wavelets and Other Filtering Methods in
    Finance and Economics},
  Academic Press.
}
\keyword{datasets}

\eof
\name{Band-pass variance}
\alias{bandpass.fdp}
\alias{bandpass.spp}
\alias{bandpass.spp2}
\alias{bandpass.var.spp}
\title{Bandpass Variance for Long-Memory Processes}
\description{
  Computes the band-pass variance for fractional difference (FD) or
  seasonal persistent (SP) processes using numeric integration of their
  spectral density function.
}
\usage{
bandpass.fdp(a, b, d)
bandpass.spp(a, b, d, fG)
bandpass.spp2(a, b, d1, f1, d2, f2)
bandpass.var.spp(delta, fG, J, Basis, Length)
}
\arguments{
  \item{a}{Left-hand boundary for the definite integral.}
  \item{b}{Right-hand boundary for the definite integral.}
  \item{d,delta,d1,d2}{Fractional difference parameter.}
  \item{fG,f1,f2}{Gegenbauer frequency.}
  \item{J}{Depth of the wavelet transform.}
  \item{Basis}{Logical vector representing the adaptive basis.}
  \item{Length}{Number of elements in Basis.}
}
\value{
  Band-pass variance for the FD or SP process between \eqn{a} and
  \eqn{b}.
}
\details{
  See references.
}
\references{
  McCoy, E. J., and A. T. Walden (1996)
  Wavelet analysis and synthesis of stationary long-memory processes,
  \emph{Journal for Computational and Graphical Statistics}, \bold{5},
  No. 1, 26-56.

  Whitcher, B. (2001)
  Simulating Gaussian stationary processes with unbounded spectra,
  \emph{Journal for Computational and Graphical Statistics}, \bold{10},
  No. 1, 112-134.
}
\seealso{}
%\examples{}
\author{B. Whitcher}
\keyword{ts}

\eof
\name{barbara}
\alias{barbara}
\title{Barbara Test Image}
\description{
  The Barbara image comes from Allen Gersho's lab at the University of
  California, Santa Barbara.
}
\usage{data(barbara)
}
\format{A 256 \eqn{\times}{x} 256 matrix.
}
\source{Internet.
}
%\references{}
\keyword{datasets}

\eof
\name{basis}
\alias{basis}
\title{Produce Boolean Vector from Wavelet Basis Names}
\description{
  Produce a vector of zeros and ones from a vector of basis names.
}
\usage{basis(x, basis.names)
}
\arguments{
  \item{x}{}
  \item{basis.names}{}
}
\value{
  Vector of zeros and ones.
}
\details{
  None.
}
%\references{}
\seealso{
  \code{\link{dwpt}}.
}
\examples{
data(acvs.andel8)
x <- hosking.sim(1024, acvs.andel8[,2])
x.dwpt <- dwpt(x, "la8", 7)
## Select orthonormal basis from wavelet packet tree
x.basis <- basis(x.dwpt, c("w1.1","w2.1","w3.0","w4.3","w5.4","w6.10",
                           "w7.22","w7.23"))
for(i in 1:length(x.dwpt))
  x.dwpt[[i]] <- x.basis[i] * x.dwpt[[i]]
## Resonstruct original series using selected orthonormal basis
y <- idwpt(x.dwpt, x.basis)
par(mfrow=c(2,1), mar=c(5-1,4,4-1,2))
plot.ts(x, xlab="", ylab="", main="Original Series")
plot.ts(y, xlab="", ylab="", main="Reconstructed Series")
}
\keyword{ts}

\eof
\name{blocks}
\alias{blocks}
\title{A Piecewise-Constant Function}
\description{
    \deqn{blocks(x) = \sum_{j=1}^{11}(1 + {\rm sign}(x-p_j)) h_j / 2}{%
      blocks(x) = sum[j=1,11] (1 + sign(x - p_j)) h_j/2}
}
\usage{data(blocks)
}
\format{A vector containing 512 observations.
}
\source{S+WAVELETS.
}
\references{
  Bruce, A., and H.-Y. Gao (1996)
  \emph{Applied Wavelet Analysis with S-PLUS}, Springer: New York.
}
\keyword{datasets}

\eof
\name{brick.wall}
\alias{brick.wall}
\alias{dwpt.brick.wall}
\title{Replace Boundary Wavelet Coefficients with Missing Values}
\description{
  Sets the first \eqn{n} wavelet coefficients to \code{NA}.
}
\usage{brick.wall(x, wf, method="modwt")
dwpt.brick.wall(x, wf, n.levels, method="modwpt") 
}
\arguments{
  \item{x}{DWT/MODWT/DWPT/MODWPT object}
  \item{wf}{Character string; name of wavelet filter}
  \item{method}{Either \code{\link{dwt}} or \code{\link{modwt}} for
    \code{brick.wall}, or either \code{\link{dwpt}} or
    \code{\link{modwpt}} for \code{dwpt.brick.wall}}
  \item{n.levels}{depth of the wavelet transform}
}
\value{
  Same object as \code{x} only with some missing values.
}
\details{
  The fact that observed time series are finite causes boundary issues.
  One way to get around this is to simply remove any wavelet coefficient
  computed involving the boundary.  This is done here by replacing
  boundary wavelet coefficients with \code{NA}.
}
\references{
  Lindsay, R. W., D. B. Percival and D. A. Rothrock (1996).
  The discrete wavelet transform and the scale anlaysis of the
  surface properties of sea ice,
  \emph{IEEE Transactions on Geoscience and Remote Sensing}, \bold{34},
  No.~3, 771-787.

  Percival, D. B. and A. T. Walden (2000)
  \emph{Wavelet Methods for Time Series Analysis},
  Cambridge University Press.
}
%\seealso{}
%\examples{}
\author{B. Whitcher}
\keyword{ts}

\eof
\name{convolve2D}
\alias{convolve2D}
\title{Fast Column-wise Convolution of a Matrix}
\description{
  Use the Fast Fourier Transform to perform convolutions between a
  sequence and each column of a matrix.
}
\usage{
convolve2D(x, y, conj = TRUE, type = c("circular", "open"))
}
\arguments{
  \item{x}{\eqn{M{\times}N} matrix.}
  \item{y}{numeric sequence of length \eqn{N}.}
  \item{conj}{logical; if \code{TRUE}, take the complex \emph{conjugate}
     before back-transforming (default, and used for usual convolution).}
  \item{type}{character; one of \code{"circular"}, \code{"open"}
     (beginning of word is ok).  For \code{circular}, the two sequences
     are treated as \emph{circular}, i.e., periodic.

     For \code{open} and \code{filter}, the sequences are padded with '0's
     (from left and right) first; \code{"filter"} returns the middle
     sub-vector of \code{"open"}, namely, the result of running a
     weighted mean of \code{x} with weights \code{y}.}
}
\value{
  
}
\details{
  This is a corrupted version of \code{convolve} made by replacing
  \code{fft} with \code{mvfft} in a few places.  It would be nice to
  submit this to the R Developers for inclusion.
}
%\references{}
\seealso{
  \code{\link{convolve}}
}
%\examples{}
\author{B. Whitcher}
\keyword{ts}

\eof
\name{cpi}
\alias{cpi}
\title{U.S. Consumer Price Index}
\description{
  Monthly U.S. consumer price index from 1948:1 to 1999:12.
}
\usage{data(cpi)
}
\format{A vector containing 624 observations.
}
\source{Unknown.
}
\references{
  Gencay, R., F. Selcuk and B. Whitcher (2001)
  \emph{An Introduction to Wavelets and Other Filtering Methods in
    Finance and Economics},
  Academic Press.
}
\keyword{datasets}

\eof
\name{dau}
\alias{dau}
\title{Digital Photograph of Ingrid Daubechies}
\description{
  A digital photograph of Ingrid Daubechies taken at the 1993 AMS winter
  meetings in San Antonio, Texas.  The photograph was taken by David
  Donoho with a Canon XapShot video still frame camera.
}
\usage{data(dau)
}
\format{A 256 \eqn{\times}{x} 256 matrix.
}
\source{S+WAVELETS.
}
\references{
  Bruce, A., and H.-Y. Gao (1996)
  \emph{Applied Wavelet Analysis with S-PLUS}, Springer: New York.
}
\keyword{datasets}

\eof
\name{denoise.2d}
\alias{denoise.dwt.2d}
\alias{denoise.modwt.2d}
\title{Denoise an Image via the 2D Discrete Wavelet Transform}
\description{
  Perform simple de-noising of an image using the two-dimensional
  discrete wavelet transform.
}
\usage{
denoise.dwt.2d(x, wf = "la8", J = 4, method = "universal", H = 0.5, 
               noise.dir = 3, rule = "hard")
denoise.modwt.2d(x, wf = "la8", J = 4, method = "universal", H = 0.5, 
                 rule = "hard") 
}
\arguments{
  \item{x}{input matrix (image)}
  \item{wf}{name of the wavelet filter to use in the decomposition}
  \item{J}{depth of the decomposition, must be a number less than or
    equal to \eqn{\log_2(\min\{M,N\})}{log(min{M,N},2)}}
  \item{method}{character string describing the threshold applied, only
    \code{"universal"} and \code{"long-memory"} are currently
    implemented}
  \item{H}{self-similarity or Hurst parameter to indicate spectral
    scaling, white noise is 0.5}
  \item{noise.dir}{number of directions to estimate background noise
    standard deviation, the default is 3 which produces a unique
    estimate of the background noise for each spatial direction}
  \item{rule}{either a \code{"hard"} or \code{"soft"} thresholding rule
    may be used}
}
\value{
  Image of the same dimension as the original but with high-freqency
  fluctuations removed.
}
\details{
  See \code{\link{Thresholding}}.
}
\references{
  See \code{\link{Thresholding}} for references concerning de-noising in
  one dimension.
}
\seealso{\code{\link{Thresholding}}}
\examples{
## Xbox image
data(xbox)
n <- NROW(xbox)
xbox.noise <- xbox + matrix(rnorm(n*n, sd=.15), n, n)
par(mfrow=c(2,2), cex=.8, pty="s")
image(xbox.noise, col=rainbow(128), main="Original Image")
image(denoise.dwt.2d(xbox.noise, wf="haar"), col=rainbow(128),
      zlim=range(xbox.noise), main="Denoised image")
image(xbox.noise - denoise.dwt.2d(xbox.noise, wf="haar"), col=rainbow(128),
      zlim=range(xbox.noise), main="Residual image")

## Daubechies image
data(dau)
n <- NROW(dau)
dau.noise <- dau + matrix(rnorm(n*n, sd=10), n, n)
par(mfrow=c(2,2), cex=.8, pty="s")
image(dau.noise, col=rainbow(128), main="Original Image")
dau.denoise <- denoise.modwt.2d(dau.noise, wf="d4", rule="soft")
image(dau.denoise, col=rainbow(128), zlim=range(dau.noise),
      main="Denoised image")
image(dau.noise - dau.denoise, col=rainbow(128), main="Residual image")
}
\author{B. Whitcher}
\keyword{ts}

\eof
\name{doppler}
\alias{doppler}
\title{Sinusoid with Changing Amplitude and Frequency}
\description{
  \deqn{doppler(x) = \sqrt{x(1 - x)}
    \sin\left(\frac{2.1\pi}{x+0.05}\right)}{%
    doppler(x) = sqrt{x(1-x)} sin[(2.1*pi)/(x+0.05)]}
}
\usage{data(doppler)
}
\format{A vector containing 512 observations.
}
\source{S+WAVELETS.
}
\references{
  Bruce, A., and H.-Y. Gao (1996)
  \emph{Applied Wavelet Analysis with S-PLUS}, Springer: New York.
}
\keyword{datasets}

\eof
\name{dpss.taper}
\alias{dpss.taper}
\title{Calculating Thomson's Spectral Multitapers by Inverse Iteration}
\description{
  The following function links the subroutines in "bell-p-w.o" to an 
  R function in order to compute discrete prolate spheroidal 
  sequences (dpss).
}
\usage{dpss.taper(n, k, nw = 4, nmax = 2^(ceiling(log(n, 2))))
}
\arguments{
  \item{n}{length of data taper(s)}
  \item{k}{number of data tapers; 1, 2, 3, ... (do not use 0!)}
  \item{nw}{product of length and half-bandwidth parameter (w)}
  \item{nmax}{maximum possible taper length, necessary for FORTRAN code}
}
\value{
  \item{v}{matrix of data tapers (cols = tapers)}
  \item{eigen}{eigenvalue associated with each data taper}
  \item{iter}{total number of iterations performed}
  \item{n}{same as input}
  \item{w}{half-bandwidth parameter}
  \item{ifault}{0 indicates success, see documentation for "bell-p-w"
    for information on non-zero values}
}
\details{
  Spectral estimation using a set of orthogonal tapers is becoming
  widely used and appreciated in scientific research.  It produces direct
  spectral estimates with more than 2 df at each Fourier frequency,
  resulting in spectral estimators with reduced variance.  Computation of
  the orthogonal tapers from the basic defining equation is difficult,
  however, due to the instability of the calculations -- the eigenproblem
  is very poorly conditioned.  In this article the severe numerical
  instability problems are illustrated and then a technique for stable
  calculation of the tapers -- namely, inverse iteration -- is
  described. Each iteration involves the solution of a matrix equation.
  Because the matrix has Toeplitz form, the Levinson recursions are used
  to rapidly solve the matrix equation.  FORTRAN code for this method is
  available through the Statlib archive.  An alternative stable method is
  also briefly reviewed.
}
\references{
  B. Bell, D. B. Percival, and A. T. Walden (1993)
  Calculating Thomson's spectral multitapers by inverse iteration,
  \emph{Journal of Computational and Graphical Statistics},
  \bold{2}, No. 1, 119-130.

  Percival, D. B. and A. T. Walden (1993)
  \emph{Spectral Estimation for Physical Applications: Multitaper and
    Conventional Univariate Techniques},
  Cambridge University Press.

}
\seealso{
  \code{\link{sine.taper}}.
}
%\examples{}
\author{B. Whitcher}
\keyword{ts}

\eof
\name{dualfilt1}
\alias{dualfilt1}
\title{Kingsbury's Q-filters for the Dual-Tree Complex DWT}
\description{
}
\usage{
dualfilt1()
}
\arguments{None.
}
\value{
  \item{af}{List ($i = 1,2$) - analysis filters for tree $i$}
  \item{sf}{List ($i = 1,2$) - synthesis filters for tree $i$}
  Note: \code{af[[2]]} is the reverse of \code{af[[1]]}.
}
\details{
  These cofficients are rounded to 8 decimal places.
}
\references{
  Kingsbury, N.G. (2000).  A dual-tree complex wavelet transform with
  improved orthogonality and symmetry properties, \emph{Proceedings of
    the IEEE Int. Conf. on Image Proc.} (ICIP).

  WAVELET SOFTWARE AT POLYTECHNIC UNIVERSITY, BROOKLYN, NY\\
  {\tt http://taco.poly.edu/WaveletSoftware/}
}
\seealso{
  \code{\link{dualtree}}
}
%\examples{}
\author{Matlab: S. Cai, K. Li and I. Selesnick; R port: B. Whitcher}
\keyword{ts}

\eof
\name{dwpt.2d}
\alias{dwpt.2d}
\alias{idwpt.2d}
%\alias{modwpt.2d}
\title{(Inverse) Discrete Wavelet Packet Transforms in Two Dimensions}
\description{
  All possible filtering combinations (low- and high-pass) are performed
  to decompose a matrix or image.  The resulting coefficients are
  associated with a quad-tree structure corresponding to a
  partitioning of the two-dimensional frequency plane.
}
\usage{dwpt.2d(x, wf="la8", J=4, boundary="periodic")
idwpt.2d(y, y.basis)
%modwpt.2d(x, wf="la8", J=4, boundary="periodic")
}
\arguments{
  \item{x}{
    a matrix or image containing the data be to decomposed.  This
    ojbect must be dyadic (power of 2) in length in each dimension.
  }
  \item{wf}{
    Name of the wavelet filter to use in the decomposition.  By default
    this is set to \code{"la8"}, the Daubechies orthonormal compactly
    supported wavelet of length \eqn{L=8} (Daubechies, 1992), least
    asymmetric family. 
  }
  \item{J}{
    Specifies the depth of the decomposition.  This must be a number
    less than or equal to \eqn{\log(\mbox{length}(x),2)}.
  }
  \item{boundary}{
    Character string specifying the boundary condition.   If
    \code{boundary=="periodic"} the default, then the vector you
    decompose is assumed to be periodic on its defined interval,\cr
    if \code{boundary=="reflection"}, the vector beyond its boundaries
    is assumed to be a symmetric reflection of itself.
  }
  \item{y}{\code{dwpt.2d} object (list-based structure of matrices)}
  \item{y.basis}{Boolean vector, the same length as \eqn{y}, where
    \code{TRUE} means the basis tensor should be used in the
    reconstruction.}
}
\value{
  Basically, a list with the following components 
  \item{w?.?-w?.?}{Wavelet coefficient matrices (images).  The first
    index is associated with the scale of the decomposition while the
    second is associated with the frequency partition within that
    level.  The left and right strings, separated by the dash `-',
    correspond to the first \eqn{(x)} and second \eqn{(y)} dimensions.}
  \item{wavelet}{Name of the wavelet filter used.}
  \item{boundary}{How the boundaries were handled.}
}
\details{
  The code implements the two-dimensional DWPT using the pyramid
  algorithm of Mallat (1989).
}
\references{
  Mallat, S. G. (1989)
  A theory for multiresolution signal decomposition: the wavelet
  representation,
  \emph{IEEE Transactions on Pattern Analysis and Machine Intelligence},
  \bold{11}, No. 7, 674-693.

  Wickerhauser, M. V. (1994)
  \emph{Adapted Wavelet Analysis from Theory to Software},
  A K Peters.
}
\seealso{
  \code{\link{dwt.2d}}, \code{\link{modwt.2d}}, \code{\link{wave.filter}}.
}
%\examples{}
\author{B. Whitcher}
\keyword{ts}

\eof
\name{dwpt}
\alias{dwpt}
\alias{idwpt}
\alias{modwpt}
\title{(Inverse) Discrete Wavelet Packet Transforms}
\description{
  All possible filtering combinations (low- and high-pass) are performed
  to decompose a vector or time series.  The resulting coefficients are
  associated with a binary tree structure corresponding to a
  partitioning of the frequency axis.
}
\usage{dwpt(x, wf="la8", n.levels=4, boundary="periodic")
idwpt(y, y.basis)
modwpt(x, wf = "la8", n.levels = 4, boundary = "periodic")
}
\arguments{
  \item{x}{
    a vector or time series containing the data be to decomposed.  This
    must be a dyadic length vector (power of 2).
  }
  \item{wf}{
    Name of the wavelet filter to use in the decomposition.  By default
    this is set to \code{"la8"}, the Daubechies orthonormal compactly
    supported wavelet of length \eqn{L=8} (Daubechies, 1992), least
    asymmetric family. 
  }
  \item{n.levels}{
    Specifies the depth of the decomposition.  This must be a number
    less than or equal to \eqn{\log(\mbox{length}(x),2)}.
  }
  \item{boundary}{
    Character string specifying the boundary condition.   If
    \code{boundary=="periodic"} the default, then the vector you
    decompose is assumed to be periodic on its defined interval,\cr
    if \code{boundary=="reflection"}, the vector beyond its boundaries
    is assumed to be a symmetric reflection of itself.
  }
  \item{y}{}
  \item{y.basis}{}
}
\value{
  Basically, a list with the following components
  \item{w?.?}{Wavelet coefficient vectors.  The first index is
    associated with the scale of the decomposition while the second is
    associated with the frequency partition within that level.}
  \item{wavelet}{Name of the wavelet filter used.}
  \item{boundary}{How the boundaries were handled.}
}
\details{
  The code implements the one-dimensional DWPT using the pyramid
  algorithm (Mallat, 1989).
}
\references{
  Mallat, S. G. (1989)
  A theory for multiresolution signal decomposition: the wavelet
  representation,
  \emph{IEEE Transactions on Pattern Analysis and Machine Intelligence},
  \bold{11}, No. 7, 674-693.

  Percival, D. B. and A. T. Walden (2000)
  \emph{Wavelet Methods for Time Series Analysis},
  Cambridge University Press.

  Wickerhauser, M. V. (1994)
  \emph{Adapted Wavelet Analysis from Theory to Software},
  A K Peters.
}
\seealso{
  \code{\link{dwt}}, \code{\link{modwpt}}, \code{\link{wave.filter}}.
}
\examples{
data(mexm)
J <- 4
mexm.mra <- mra(log(mexm), "mb8", J, "modwt", "reflection")
mexm.nomean <- ts(
  apply(matrix(unlist(mexm.mra), ncol=J+1, byrow=FALSE)[,-(J+1)], 1, sum), 
  start=1957, freq=12)
mexm.dwpt <- dwpt(mexm.nomean[-c(1:4)], "mb8", 7, "reflection")
}
\author{B. Whitcher}
\keyword{ts}

\eof
\name{dwpt.sim}
\alias{dwpt.sim}
\title{Simulate Seasonal Persistent Processes Using the DWPT}
\description{
  A seasonal persistent process may be characterized by a spectral
  density function with an asymptote occuring at a particular frequency
  in \eqn{[0,\frac{1}{2})}{[0,1/2)}.  It's time domain representation
  was first noted in passing by Hosking (1981).  Although an exact
  time-domain approach to simulation is possible, this function utilizes
  the discrete wavelet packet transform (DWPT).
}
\usage{dwpt.sim(N, wf, delta, fG, M=2, adaptive=TRUE, epsilon=0.05)
}
\arguments{
  \item{N}{Length of time series to be generated.}
  \item{wf}{Character string for the wavelet filter.}
  \item{delta}{Long-memory parameter for the seasonal persistent process.}
  \item{fG}{Gegenbauer frequency.}
  \item{M}{Actual length of simulated time series.}
  \item{adaptive}{Logical; if \code{TRUE} the orthonormal basis used in
    the DWPT is adapted to the ideal spectrum, otherwise the orthonormal
    basis is performed to a maximum depth.}
  \item{epsilon}{Threshold for adaptive basis selection.}
}
\value{
  Time series of length \code{N}.
}
\details{
  Two subroutines are used, the first selects an adaptive orthonormal
  basis for the true spectral density function (SDF) while the second
  computes the bandpass variances associated with the chosen orthonormal
  basis and SDF.  Finally, when \eqn{$M>N$}{\code{M} > \code{N}} a
  uniform random variable is generated in order to select a random piece
  of the simulated time series.  For more details see Whitcher (2001).
}
\references{
  Hosking, J. R. M. (1981)
  Fractional Differencing,
  \emph{Biometrika}, \bold{68}, No. 1, 165-176.
  
  Whitcher, B. (2001)
  Simulating Gaussian Stationary Time Series with Unbounded Spectra,
  \emph{Journal of Computational and Graphical Statistics}, \bold{10},
  No. 1, 112-134.
}
\seealso{
  \code{\link{hosking.sim}} for an exact time-domain method and
  \code{\link{wave.filter}} for a list of available wavelet filters.
}
\examples{
## Generate monthly time series with annual oscillation
## library(ts) is required in order to access acf()
x <- dwpt.sim(256, "mb16", .4, 1/12, M=4, epsilon=.001)
par(mfrow=c(2,1))
plot.ts(x)
if(!is.loaded("acf", "ts"))
  library(ts)
acf(x, lag.max=128, ylim=c(-.6,1))
data(acvs.andel8)
lines(acvs.andel8$lag[1:128], acvs.andel8$acf[1:128], col=2)
}
\author{B. Whitcher}
\keyword{ts}

\eof
\name{dwt.2d}
\alias{dwt.2d}
\alias{idwt.2d}
\title{Two-Dimensional Discrete Wavelet Transform}
\description{
  Performs a separable two-dimensional discrete wavelet transform (DWT)
  on a matrix of dyadic dimensions.
}
\usage{dwt.2d(x, wf, J = 4, boundary = "periodic")
idwt.2d(y)
}
\arguments{
  \item{x}{input matrix (image)}
  \item{wf}{name of the wavelet filter to use in the decomposition}
  \item{J}{depth of the decomposition, must be a number less than or
    equal to \eqn{\log_2(\min\{M,N\})}{log(min{M,N},2)}}
  \item{boundary}{only \code{"periodic"} is currently implemented}
  \item{y}{an object of class \code{dwt.2d}}
}
\value{
  List structure containing the \eqn{3J+1} sub-matrices from the
  decomposition.
}
\details{
  See references.
}
\references{
  Mallat, S. (1998)
  \emph{A Wavelet Tour of Signal Processing},
  Academic Press.

  Vetterli, M. and J. Kovacevic (1995)
  \emph{Wavelets and Subband Coding},
  Prentice Hall.
}
\seealso{
  \code{\link{modwt.2d}}.
}
\examples{
## Xbox image
data(xbox)
xbox.dwt <- dwt.2d(xbox, "haar", 3)
par(mfrow=c(1,1), pty="s")
plot.dwt.2d(xbox.dwt)
par(mfrow=c(2,2), pty="s")
image(1:dim(xbox)[1], 1:dim(xbox)[2], xbox, xlab="", ylab="",
      main="Original Image")
image(1:dim(xbox)[1], 1:dim(xbox)[2], idwt.2d(xbox.dwt), xlab="", ylab="",
      main="Wavelet Reconstruction")
image(1:dim(xbox)[1], 1:dim(xbox)[2], xbox - idwt.2d(xbox.dwt),
      xlab="", ylab="", main="Difference")

## Daubechies image
data(dau)
par(mfrow=c(1,1), pty="s")
image(dau, col=rainbow(128))
sum(dau^2)
dau.dwt <- dwt.2d(dau, "d4", 3)
plot.dwt.2d(dau.dwt)
sum(plot.dwt.2d(dau.dwt, plot=FALSE)^2)
}
\author{B. Whitcher}
\keyword{ts}

\eof
\name{dwt.3d}
\alias{dwt.3d}
\alias{idwt.3d}
\title{Three Dimensional Separable Discrete Wavelet Transform}
\description{
}
\usage{dwt.3d(x, wf, J=4, boundary="periodic")
idwt.3d(y)
}
\arguments{
  \item{x}{input array}
  \item{wf}{name of the wavelet filter to use in the decomposition}
  \item{J}{depth of the decomposition, must be a number less than or
    equal to \eqn{\log_2(\min\{X,Y,Z\})}{log(min{Z,Y,Z},2)}}
  \item{boundary}{only \code{"periodic"} is currently implemented}
  \item{y}{an object of class \code{dwt.3d}}
}
\value{
}
\details{
}
\references{
}
\seealso{
}
%\examples{}
\author{B. Whitcher}
\keyword{ts}

\eof
\name{dwt}
\alias{dwt}
\alias{dwt.nondyadic}
\alias{idwt}
\title{Discrete Wavelet Transform (DWT)}
\description{
  This function performs a level \eqn{J} decomposition of the input
  vector or time series using the pyramid algorithm (Mallat 1989).
}
\usage{
dwt(x, wf="la8", n.levels=4, boundary="periodic")
dwt.nondyadic(x)
}
\arguments{
  \item{x}{a vector or time series containing the data be to
    decomposed.  This must be a dyadic length vector (power of 2).}
  \item{wf}{
    Name of the wavelet filter to use in the decomposition.  By default
    this is set to \code{"la8"}, the Daubechies orthonormal compactly
    supported wavelet of length \eqn{L=8} (Daubechies, 1992), least
    asymmetric family. 
  }
  \item{n.levels}{
    Specifies the depth of the decomposition.  This must be a number
    less than or equal to
    \eqn{\log(\mbox{length}(x),2)}{log(length(x),2)}.
  }
  \item{boundary}{
    Character string specifying the boundary condition.   If
    \code{boundary=="periodic"} the default, then the vector you
    decompose is assumed to be periodic on its defined interval,\cr
    if \code{boundary=="reflection"}, the vector beyond its boundaries
    is assumed to be a symmetric reflection of itself.
  }
}
\value{
  Basically, a list with the following components
  \item{d?}{Wavelet coefficient vectors.}
  \item{s?}{Scaling coefficient vector.}
  \item{wavelet}{Name of the wavelet filter used.}
  \item{boundary}{How the boundaries were handled.}
}
\details{
  The code implements the one-dimensional DWT using the pyramid
  algorithm (Mallat, 1989).  The actual transform is performed in C
  using pseudocode from Percival and Walden (2001).  That means
  convolutions, not inner products, are used to apply the wavelet
  filters.

  For a non-dyadic length vector or time series, \code{dwt.nondyadic}
  pads with zeros, performs the orthonormal DWT on this dyadic length
  series and then truncates the wavelet coefficient vectors
  appropriately.
}
\references{
  Daubechies, I. (1992)
  \emph{Ten Lectures on Wavelets},
  CBMS-NSF Regional Conference Series in Applied Mathematics,
  SIAM: Philadelphia.

  Gencay, R., F. Selcuk and B. Whitcher (2001)
  \emph{An Introduction to Wavelets and Other Filtering Methods in
    Finance and Economics},
  Academic Press.
  
  Mallat, S. G. (1989)
  A theory for multiresolution signal decomposition: the wavelet
  representation,
  \emph{IEEE Transactions on Pattern Analysis and Machine Intelligence},
  \bold{11}, No. 7, 674-693.

  Percival, D. B. and A. T. Walden (2000)
  \emph{Wavelet Methods for Time Series Analysis},
  Cambridge University Press.
}
\seealso{
  \code{\link{modwt}}, \code{\link{mra}}.
}
\examples{
## Figures 4.17 and 4.18 in Gencay, Selcuk and Whitcher (2001).
data(ibm)     
ibm.returns <- diff(log(ibm))
## Haar
ibmr.haar <- dwt(ibm.returns, "haar")
names(ibmr.haar) <- c("w1", "w2", "w3", "w4", "v4")
## plot partial Haar DWT for IBM data
par(mfcol=c(6,1), pty="m", mar=c(5-2,4,4-2,2))
plot.ts(ibm.returns, axes=FALSE, ylab="", main="(a)")
for(i in 1:4)
  plot.ts(up.sample(ibmr.haar[[i]], 2^i), type="h", axes=FALSE,
          ylab=names(ibmr.haar)[i])
plot.ts(up.sample(ibmr.haar$v4, 2^4), type="h", axes=FALSE,
        ylab=names(ibmr.haar)[5])
axis(side=1, at=seq(0,368,by=23), 
     labels=c(0,"",46,"",92,"",138,"",184,"",230,"",276,"",322,"",368))
## LA(8)
ibmr.la8 <- dwt(ibm.returns, "la8")
names(ibmr.la8) <- c("w1", "w2", "w3", "w4", "v4")
## must shift LA(8) coefficients
ibmr.la8$w1 <- c(ibmr.la8$w1[-c(1:2)], ibmr.la8$w1[1:2])
ibmr.la8$w2 <- c(ibmr.la8$w2[-c(1:2)], ibmr.la8$w2[1:2])
for(i in names(ibmr.la8)[3:4])
  ibmr.la8[[i]] <- c(ibmr.la8[[i]][-c(1:3)], ibmr.la8[[i]][1:3])
ibmr.la8$v4 <- c(ibmr.la8$v4[-c(1:2)], ibmr.la8$v4[1:2])
## plot partial LA(8) DWT for IBM data
par(mfcol=c(6,1), pty="m", mar=c(5-2,4,4-2,2))
plot.ts(ibm.returns, axes=FALSE, ylab="", main="(b)")
for(i in 1:4)
  plot.ts(up.sample(ibmr.la8[[i]], 2^i), type="h", axes=FALSE,
          ylab=names(ibmr.la8)[i])
plot.ts(up.sample(ibmr.la8$v4, 2^4), type="h", axes=FALSE,
        ylab=names(ibmr.la8)[5])
axis(side=1, at=seq(0,368,by=23), 
  labels=c(0,"",46,"",92,"",138,"",184,"",230,"",276,"",322,"",368))
}
\author{B. Whitcher}
\keyword{ts}

\eof
\name{exchange}
\alias{exchange}
\title{Exchange Rates Between the Deutsche Mark, Japanese Yen and U.S. Dollar}
\description{
  Monthly foreign exchange rates for the Deutsche Mark - U.S. Dollar
  (DEM-USD) and Japanese Yen - U.S. Dollar (JPY-USD) starting in 1970.
}
\usage{data(exchange)
}
\format{A bivariate time series containing 348 observations.
}
\source{Unknown.
}
\references{
  Gencay, R., F. Selcuk and B. Whitcher (2001)
  \emph{An Introduction to Wavelets and Other Filtering Methods in
    Finance and Economics},
  Academic Press.
}
\keyword{datasets}

\eof
\name{Dual-tree Filter Banks}
\alias{afb}
\alias{afb2D}
\alias{afb2D.A}
\alias{sfb}
\alias{sfb2D}
\alias{sfb2D.A}
\title{Filter Banks for Dual-Tree Wavelet Transforms}
\description{
  Analysis and synthesis filter banks used in dual-tree wavelet
  algorithms.
}
\usage{
afb(x, af)
afb2D(x, af1, af2 = NULL)
afb2D.A(x, af, d)
sfb(lo, hi, sf)
sfb2D(lo, hi, sf1, sf2 = NULL)
sfb2D.A(lo, hi, sf, d)
}
\arguments{
  \item{x}{vector or matrix of observations}
  \item{af}{analysis filters.  First element of the list is the low-pass
    filter, second element is the high-pass filter.}
  \item{af1,af2}{analysis filters for the first and second dimension of
    a 2D array.}
  \item{sf}{synthesis filters.  First element of the list is the
    low-pass filter, second element is the high-pass filter.}
  \item{sf1,sf2}{synthesis filters for the first and second dimension of
    a 2D array.}
  \item{d}{dimension of filtering (d = 1 or 2)}
  \item{lo}{low-frequecy coefficients}
  \item{hi}{high-frequency coefficients}
}
\value{
  In one dimension the output for the analysis filter bank (\code{afb})
  is a list with two elements
  \item{lo}{Low frequecy output}
  \item{hi}{High frequency output}
  and the output for the synthesis filter bank (\code{sfb}) is the
  output signal.
  
  In two dimensions the output for the analysis filter bank
  (\code{afb2D}) is a list with four elements
  \item{lo}{low-pass subband}
  \item{hi[[1]]}{'lohi' subband}
  \item{hi[[2]]}{'hilo' subband}
  \item{hi[[3]]}{'hihi' subband}
  and the output for the synthesis filter bank (\code{sfb2D}) is the
  output array.

  The functions \code{afb2D.A} and \code{sfb2D.A} implement the
  convolutions, either for analysis or synthesis, in one dimension
  only.  Thus, they are the workhorses of \code{afb2D} and
  \code{sfb2D}.  The output for the analysis filter bank along one
  dimension (\code{afb2D.A}) is a list with two elements
  \item{lo}{low-pass subband}
  \item{hi}{high-pass subband}
  where the dimension of analysis will be half its original length.  The
  output for the synthesis filter bank along one dimension
  (\code{sfb2D.A}) will be the output array, where the dimension of
  synthesis will be twice its original length.
}
%\details{}
\references{
  WAVELET SOFTWARE AT POLYTECHNIC UNIVERSITY, BROOKLYN, NY\\
  {\tt http://taco.poly.edu/WaveletSoftware/}
}
%\seealso{}
\examples{
## EXAMPLE: afb, sfb
af = farras()$af
sf = farras()$sf
x = rnorm(64)
x.afb = afb(x, af)
lo = x.afb$lo
hi = x.afb$hi
y = sfb(lo, hi, sf)
err = x - y
max(abs(err))

## EXAMPLE: afb2D, sfb2D
x = matrix(rnorm(32*64), 32, 64)
af = farras()$af
sf = farras()$sf
x.afb2D = afb2D(x, af, af)
lo = x.afb2D$lo
hi = x.afb2D$hi
y = sfb2D(lo, hi, sf, sf)
err = x - y
max(abs(err))

## Example: afb2D.A, sfb2D.A
x = matrix(rnorm(32*64), 32, 64)
af = farras()$af
sf = farras()$sf
x.afb2D.A = afb2D.A(x, af, 1)
lo = x.afb2D.A$lo
hi = x.afb2D.A$hi
y = sfb2D.A(lo, hi, sf, 1)
err = x - y
max(abs(err))
}
\author{Matlab: S. Cai, K. Li and I. Selesnick; R port: B. Whitcher}
\keyword{ts}

\eof
\name{fdp.mle}
\alias{fdp.mle}
\title{Wavelet-based Maximum Likelihood Estimation for a Fractional
  Difference Process}
\description{
  Parameter estimation for a fractional difference (long-memory,
  self-similar) process is performed via maximum likelihood on the
  wavelet coefficients.
}
\usage{fdp.mle(y, wf, J=log(length(y),2))
}
\arguments{
  \item{y}{Dyadic length time series.}
  \item{wf}{Name of the wavelet filter to use in the decomposition.  See
    \code{\link{wave.filter}} for those wavelet filters available.}
  \item{J}{Depth of the discrete wavelet transform.}
}
\value{
  List containing the maximum likelihood estimates (MLEs) of \eqn{d} and
  \eqn{\sigma^2}, along with the value of the likelihood for those
  estimates.
}
\details{
  The variance-covariance matrix of the original time series is
  approximated by its wavelet-based equivalent.  A Whittle-type
  likelihood is then constructed where the sums of squared wavelet
  coefficients are compared to bandpass filtered version of the true
  spectrum.  Minimization occurs only for the fractional difference
  parameter \eqn{d}, while variance is estimated afterwards.
}
\references{
  M. J. Jensen (2000)
  An alternative maximum likelihood estimator of long-memory processes
  using compactly supported wavelets,
  \emph{Journal of Economic Dynamics and Control}, \bold{24}, No. 3,
  361-387.

  McCoy, E. J., and A. T. Walden (1996)
  Wavelet analysis and synthesis of stationary long-memory processes,
  \emph{Journal for Computational and Graphical Statistics}, \bold{5},
  No. 1, 26-56.

  Percival, D. B. and A. T. Walden (2000)
  \emph{Wavelet Methods for Time Series Analysis},
  Cambridge University Press.
}
%\seealso{}
\examples{
## Figure 5.5 in Gencay, Selcuk and Whitcher (2001)
fdp.sdf <- function(freq, d, sigma2=1)
  sigma2 / ((2*sin(pi * freq))^2)^d
dB <- function(x) 10 * log10(x)
per <- function(z) {
  n <- length(z)
  (Mod(fft(z))**2/(2*pi*n))[1:(n \%/\% 2 + 1)]
}
data(ibm)     
ibm.returns <- diff(log(ibm))
ibm.volatility <- abs(ibm.returns)
ibm.vol.mle <- fdp.mle(ibm.volatility, "d4", 4)
freq <- 0:184/368
ibm.vol.per <- 2 * pi * per(ibm.volatility)
ibm.vol.resid <- ibm.vol.per/ fdp.sdf(freq, ibm.vol.mle$parameters[1])
par(mfrow=c(1,1), las=0, pty="m")
plot(freq, dB(ibm.vol.per), type="l", xlab="Frequency", ylab="Spectrum")
lines(freq, dB(fdp.sdf(freq, ibm.vol.mle$parameters[1],
                       ibm.vol.mle$parameters[2]/2)), col=2)
}
\author{B. Whitcher}
\keyword{ts}

\eof
\name{find.adaptive.basis}
\alias{find.adaptive.basis}
\title{Determine an Orthonormal Basis for the Discrete Wavelet Packet
  Transform}
\description{
  Subroutine for use in simulating seasonal persistent processes using
  the discrete wavelet packet transform.
}
\usage{find.adaptive.basis(wf, J, fG, eps)
}
\arguments{
  \item{wf}{Character string; name of the wavelet filter.}
  \item{J}{Depth of the discrete wavelet packet transform.}
  \item{fG}{Gegenbauer frequency.}
  \item{eps}{Threshold for the squared gain function.}
}
\value{
  Boolean vector describing the orthonormal basis for the DWPT.
}
\details{
  The squared gain functions for a Daubechies (extremal phase or least
  asymmetric) wavelet family are used in a filter cascade to compute the
  value of the squared gain function for the wavelet packet filter at
  the Gengenbauer frequency.  This is done for all nodes of the wavelet
  packet table.

  The idea behind this subroutine is to approximate the relationship
  between the discrete wavelet transform and long-memory processes,
  where the squared gain function is zero at frequency zero for all
  levels of the DWT.
}
%\references{}
\seealso{
  Used in \code{\link{dwpt.sim}}.
}
%\examples{}
\author{B. Whitcher}
\keyword{ts}

\eof
\name{heavisine}
\alias{heavisine}
\title{Sine with Jumps at 0.3 and 0.72}
\description{
  \deqn{heavisine(x) = 4\sin(4{\pi}x) - \mathrm{sign}(x-0.3) -
    \mathrm{sign}(0.72-x)}{%
    heavisine(x) = 4*sin(4*pi*x) - sign(x-0.3) - sign(0.72-x)}
}
\usage{data(heavisine)
}
\format{A vector containing 512 observations.
}
\source{S+WAVELETS.
}
\references{
  Bruce, A., and H.-Y. Gao (1996)
  \emph{Applied Wavelet Analysis with S-PLUS}, Springer: New York.
}
\keyword{datasets}

\eof
\name{Hilbert}
\alias{dwt.hilbert}
\alias{dwt.hilbert.nondyadic}
\alias{idwt.hilbert}
\alias{modwt.hilbert}
\alias{imodwt.hilbert}
\alias{modwpt.hilbert}
\title{Discrete Hilbert Wavelet Transforms}
\description{
  The discrete Hilbert wavelet transforms (DHWTs) for seasonal and 
  time-varying time series analysis.  Transforms include the usual
  orthogonal (decimated), maximal-overlap (non-decimated) and
  maximal-overlap packet transforms.
}
\usage{
dwt.hilbert(x, wf, n.levels=4, boundary="periodic", ...)
dwt.hilbert.nondyadic(x, ...)
idwt.hilbert(y)
modwt.hilbert(x, wf, n.levels=4, boundary="periodic", ...)
imodwt.hilbert(y)
modwpt.hilbert(x, wf, n.levels=4, boundary="periodic")
}
\arguments{
  \item{x}{Real-valued time series or vector of observations.}
  \item{wf}{Hilbert wavelet pair}
  \item{n.levels}{Number of levels (depth) of the wavelet transform.}
  \item{boundary}{Boundary treatment, currently only \code{periodic} and
    \code{reflection}.}
  \item{y}{Hilbert wavelet transform object (list).}
  \item{...}{}
}
\value{
  
}
\details{

}
\references{
  Selesnick, I. (200X). \emph{IEEE Signal Processing Magazine}

  Selesnick, I. (200X). \emph{IEEE Transactions in Signal Processing}

  Whither, B. and P.F. Craigmile (2004).  Multivariate Spectral Analysis 
  Using Hilbert Wavelet Pairs, \emph{International Journal of Wavelets, 
  Multiresolution and Information Processing}, to appear.
}
\seealso{
  \code{\link{hilbert.filter}}
}
%\examples{}
\author{B. Whitcher}
\keyword{ts}

\eof
\name{hilbert.filter}
\alias{hilbert.filter}
\title{Select a Hilbert Wavelet Pair}
\description{
  Converts name of Hilbert wavelet pair to filter coefficients.
}
\usage{
hilbert.filter(name)
}
\arguments{
  \item{name}{Character string of Hilbert wavelet pair, see acceptable
    names below (e.g., \code{"k3l3"}).}
}
\value{
  List containing the following items:
  \item{L}{length of the wavelet filter}
  \item{h0,g0}{low-pass filter coefficients}
  \item{h1,g1}{high-pass filter coefficients}
}
\details{
  Simple \code{switch} statement selects the appropriate HWP.  There are
  two parameters that define a Hilbert wavelet pair using the notation
  of Selesnick (200X), $K$ and $L$.  Currently, the only implemented
  combinations $(K,L)$ are (3,3), (3,5), (4,2) and (4,4).
}
\references{
  Selesnick, I.W. (2001).  Hilbert transform pairs of wavelet bases. 
  \emph{IEEE Signal Processing Letters\/}~\bold{8}(6), 170--173.

  Selesnick, I.W. (2002).  The design of approximate {H}ilbert transform
  pairs of wavelet bases.  \emph{IEEE Transactions on Signal
    Processing\/}~\bold{50}(5), 1144--1152.
}
\seealso{
  \code{\link{wave.filter}}
}
%\examples{}
\author{B. Whitcher}
\keyword{ts}

\eof
\name{hosking.sim}
\alias{hosking.sim}
\title{Generate Stationary Gaussian Process Using Hosking's Method}
\description{
  Uses exact time-domain method from Hosking (1984) to generate a
  simulated time series from a specified autocovariance sequence.
}
\usage{hosking.sim(n, acvs)
}
\arguments{
  \item{n}{Length of series.}
  \item{acvs}{Autocovariance sequence of series with which to generate,
    must be of length at least \code{n}.}
}
\value{
  Length \code{n} time series from true autocovariance sequence
  \code{acvs}.
}
\details{
}
\references{
  Hosking, J. R. M. (1984)
  Modeling persistence in hydrological time series using fractional
  differencing,
  \emph{Water Resources Research}, \bold{20}, No. 12, 1898-1908.

  Percival, D. B. (1992)
  Simulating Gaussian random processes with specified spectra,
  \emph{Computing Science and Statistics}, \bold{22}, 534-538.
}
%\seealso{}
\examples{
dB <- function(x) 10 * log10(x)
per <- function (z) {
  n <- length(z)
  (Mod(fft(z))^2/(2 * pi * n))[1:(n\%/\%2 + 1)]
}
spp.sdf <- function(freq, delta, omega)
  abs(2 * (cos(2*pi*freq) - cos(2*pi*omega)))^(-2*delta)
data(acvs.andel8)
n <- 1024
z <- hosking.sim(n, acvs.andel8[,2])
per.z <- 2 * pi * per(z)
par(mfrow=c(2,1), las=1)
plot.ts(z, ylab="", main="Realization of a Seasonal Long-Memory Process")
plot(0:(n/2)/n, dB(per.z), type="l", xlab="Frequency", ylab="dB",
     main="Periodogram")
lines(0:(n/2)/n, dB(spp.sdf(0:(n/2)/n, .4, 1/12)), col=2)
}
\author{B. Whitcher}
\keyword{ts}

\eof
\name{HWP Analysis}
\alias{modhwt.coh}
\alias{modhwt.phase}
\alias{modhwt.coh.seasonal}
\alias{modhwt.phase.seasonal}
\title{Time-varying and Seasonal Analysis Using Hilbert Wavelet Pairs}
\description{
  Performs time-varying or seasonal coherence and phase anlaysis between
  two time seris using the maximal-overlap discrete Hilbert wavelet
  transform (MODHWT). 
}
\usage{
modhwt.coh(x, y, f.length = 0)
modhwt.phase(x, y, f.length = 0)
modhwt.coh.seasonal(x, y, S = 10, season = 365)
modhwt.phase.seasonal(x, y, season = 365)
}
\arguments{
  \item{x}{MODHWT object.}
  \item{y}{MODHWT object.}
  \item{f.length}{Length of the rectangular filter.}
  \item{S}{Number of "seasons".}
  \item{season}{Length of the "season".}
}
\value{
  Time-varying or seasonal coherence and phase between two time series.
  The coherence estimates are between zero and one, while the phase
  estimates are between $-\pi$ and $\pi$.
}
\details{
  The idea of seasonally-varying spectral analysis (SVSA, Madden 1986)
  is generalized using the MODWT and Hilbert wavelet pairs.  For the
  seasonal case, $S$ seasons are used to produce a consistent estimate
  of the coherence and phase.  For the non-seasonal case, a simple
  rectangular (moving-average) filter is applied to the MODHWT
  coefficients in order to produce consistent estimates.
}  
\references{
  Madden, R.A. (1986).  Seasonal variation of the 40--50 day oscillation
  in the tropics.  \emph{Journal of the Atmospheric Sciences\/}
  \bold{43\/}(24), 3138--3158.

  Whither, B. and P.F. Craigmile (2004).  Multivariate Spectral Analysis 
  Using Hilbert Wavelet Pairs, \emph{International Journal of Wavelets, 
  Multiresolution and Information Processing}, to appear.
}
\seealso{
  \code{\link{hilbert.filter}}
}
%\examples{}
\author{B. Whitcher}
\keyword{ts}

\eof
\name{ibm}
\alias{ibm}
\title{Daily IBM Stock Prices}
\description{
  Daily IBM stock prices spanning May~17, 1961 to November~2, 1962.
}
\usage{data(ibm)
}
\format{A vector containing 369 observations.
}
\source{
  Box, G. E.~P. and Jenkins, G.~M. (1976)
  \emph{Time Series Analysis: Forecasting and Control},
  Holden Day, San Francisco, 2 edition.
}
\references{
  \url{http://www-personal.buseco.monash.edu.au/~hyndman/TSDL/}
}
\keyword{datasets}

\eof
\name{japan}
\alias{japan}
\title{Japanese Gross National Product}
\description{
  Quarterly Japanese gross national product from 1955:1 to 1996:4.
}
\usage{data(japan)
}
\format{A vector containing 169 observations.
}
\source{Unknown.
}
\references{
  Gencay, R., F. Selcuk and B. Whitcher (2001)
  \emph{An Introduction to Wavelets and Other Filtering Methods in
    Finance and Economics},
  Academic Press.

  Hecq, A. (1998)
  Does seasonal adjustment induce common cycles?,
  \emph{Empirical Economics}, \bold{59}, 289-297.
}
\keyword{datasets}

\eof
\name{jumpsine}
\alias{jumpsine}
\title{Sine with Jumps at 0.625 and 0.875}
\description{
  \deqn{jumpsine(x) = 10\left( \sin(4{\pi}x) +
    I_{[0.625 < x \leq 0.875]}\right)}{%
    jumpsine(x) = 10*(sin(4*pi*x) + I_[0.625 < x <= 0.875])}
}
\usage{data(jumpsine)
}
\format{A vector containing 512 observations.
}
\source{S+WAVELETS.
}
\references{
  Bruce, A., and H.-Y. Gao (1996)
  \emph{Applied Wavelet Analysis with S-PLUS}, Springer: New York.
}
\keyword{datasets}

\eof
\name{kobe}
\alias{kobe}
\title{1995 Kobe Earthquake Data}
\description{
  Seismograph (vertical acceleration, nm/sq.sec) of the Kobe earthquake,
  recorded at Tasmania University, HobarTRUE, Australia on 16 January 1995
  beginning at 20:56:51 (GMTRUE) and continuing for 51 minutes at 1 second
  intervals.
}
\usage{data(kobe)
}
\format{A vector containing 3048 observations.
}
\source{Data management centre, Washington University.
}
\references{
  \url{http://www-personal.buseco.monash.edu.au/~hyndman/TSDL/}
}
\keyword{datasets}

\eof
\name{linchirp}
\alias{linchirp}
\title{Linear Chirp}
\description{
  \deqn{linchirp(x) = \sin(0.125 \pi n x^2)}{%
    linchirp(x) = sin(0.125*pi*n*x^2)}
}
\usage{data(linchirp)
}
\format{A vector containing 512 observations.
}
\source{S+WAVELETS.
}
\references{
  Bruce, A., and H.-Y. Gao (1996)
  \emph{Applied Wavelet Analysis with S-PLUS}, Springer: New York.
}
\keyword{datasets}

\eof
\name{mexm}
\alias{mexm}
\title{Mexican Money Supply}
\description{
  Percentage changes in monthly Mexican money supply.
}
\usage{data(mexm)
}
\format{A vector containing 516 observations.
}
\source{Unknown.
}
\references{
  Gencay, R., F. Selcuk and B. Whitcher (2001)
  \emph{An Introduction to Wavelets and Other Filtering Methods in
    Finance and Economics},
  Academic Press.
}
\keyword{datasets}

\eof
\name{modwt.2d}
\alias{modwt.2d}
\alias{imodwt.2d}
\title{Two-Dimensional Maximal Overlap Discrete Wavelet Transform}
\description{
  Performs a separable two-dimensional maximal overlap discrete wavelet
  transform (MODWT) on a matrix of arbitrary dimensions.
}
\usage{modwt.2d(x, wf, J = 4, boundary = "periodic")
imodwt.2d(y)
}
\arguments{
  \item{x}{input matrix}
  \item{wf}{name of the wavelet filter to use in the decomposition}
  \item{J}{depth of the decomposition} 
  \item{boundary}{only \code{"periodic"} is currently implemented}
  \item{y}{an object of class \code{dwt.2d}}
}
\value{
  List structure containing the \eqn{3J+1} sub-matrices from the
  decomposition.
}
\details{
  See references.
}
\references{
  Liang, J. and T. W. Parks (1994)
  A two-dimensional translation invariant wavelet representation and its
  applications,
  \emph{Proceedings ICIP-94}, Vol. 1, 66-70.

  Liang, J. and T. W. Parks (1994)
  Image coding using translation invariant wavelet transforms with
  symmetric extensions,
  \emph{IEEE Transactions on Image Processing}, \bold{7}, No. 5, 762-769.
}
\seealso{
  \code{\link{dwt.2d}}, \code{\link{shift.2d}}.
}
\examples{
## Xbox image
data(xbox)
xbox.modwt <- modwt.2d(xbox, "haar", 2)
## Level 1 decomposition
par(mfrow=c(2,2), pty="s")
image(xbox.modwt$LH1, col=rainbow(128), axes=FALSE, main="LH1")
image(xbox.modwt$HH1, col=rainbow(128), axes=FALSE, main="HH1")
frame()
image(xbox.modwt$HL1, col=rainbow(128), axes=FALSE, main="HL1")
## Level 2 decomposition
par(mfrow=c(2,2), pty="s")
image(xbox.modwt$LH2, col=rainbow(128), axes=FALSE, main="LH2")
image(xbox.modwt$HH2, col=rainbow(128), axes=FALSE, main="HH2")
image(xbox.modwt$LL2, col=rainbow(128), axes=FALSE, main="LL2")
image(xbox.modwt$HL2, col=rainbow(128), axes=FALSE, main="HL2")
sum((xbox - imodwt.2d(xbox.modwt))^2)

data(dau)
par(mfrow=c(1,1), pty="s")
image(dau, col=rainbow(128), axes=FALSE, main="Ingrid Daubechies")
sum(dau^2)
dau.modwt <- modwt.2d(dau, "d4", 2)
## Level 1 decomposition
par(mfrow=c(2,2), pty="s")
image(dau.modwt$LH1, col=rainbow(128), axes=FALSE, main="LH1")
image(dau.modwt$HH1, col=rainbow(128), axes=FALSE, main="HH1")
frame()
image(dau.modwt$HL1, col=rainbow(128), axes=FALSE, main="HL1")
## Level 2 decomposition
par(mfrow=c(2,2), pty="s")
image(dau.modwt$LH2, col=rainbow(128), axes=FALSE, main="LH2")
image(dau.modwt$HH2, col=rainbow(128), axes=FALSE, main="HH2")
image(dau.modwt$LL2, col=rainbow(128), axes=FALSE, main="LL2")
image(dau.modwt$HL2, col=rainbow(128), axes=FALSE, main="HL2")
sum((dau - imodwt.2d(dau.modwt))^2)
}
\author{B. Whitcher}
\keyword{ts}

\eof
\name{modwt.3d}
\alias{modwt.3d}
\alias{imodwt.3d}
\title{Three Dimensional Separable Discrete Wavelet Transform}
\description{
}
\usage{modwt.3d(x, wf, J=4, boundary="periodic")
imodwt.3d(y)
}
\arguments{
  \item{x}{input array}
  \item{wf}{name of the wavelet filter to use in the decomposition}
  \item{J}{depth of the decomposition} 
  \item{boundary}{only \code{"periodic"} is currently implemented}
  \item{y}{an object of class \code{modwt.3d}}
}
\value{
}
\details{
}
\references{
}
\seealso{
}
%\examples{}
\author{B. Whitcher}
\keyword{ts}

\eof
\name{modwt}
\alias{modwt}
\alias{imodwt}
\title{(Inverse) Maximal Overlap Discrete Wavelet Transform}
\description{
  This function performs a level \eqn{J} decomposition of the input
  vector using the non-decimated discrete wavelet transform. The inverse
  transform performs the reconstruction of a vector or time series from
  its maximal overlap discrete wavelet transform.
}
\usage{modwt(x, wf = "la8", n.levels = 4, boundary = "periodic")
imodwt(y)
}
\arguments{
  \item{x}{
    a vector or time series containing the data be to decomposed.  There
    is \bold{no} restriction on its length.
  }
  \item{y}{
    Object of class \code{"modwt"}.
  }
  \item{wf}{
    Name of the wavelet filter to use in the decomposition.  By default
    this is set to \code{"la8"}, the Daubechies orthonormal compactly
    supported wavelet of length \eqn{L=8} (Daubechies, 1992), least
    asymmetric family. 
  }
  \item{n.levels}{
    Specifies the depth of the decomposition.  This must be a number
    less than or equal to
    \eqn{\log_2(\mbox{length}(x))}{log(length(x),2)}.
  }
  \item{boundary}{
    Character string specifying the boundary condition.   If
    \code{boundary=="periodic"} the defaulTRUE, then the vector you
    decompose is assumed to be periodic on its defined interval,\cr
    if \code{boundary=="reflection"}, the vector beyond its boundaries
    is assumed to be a symmetric reflection of itself.
  }
}
\value{
  Object of class \code{"modwt"}, basically, a list with the following
  components 
  \item{d?}{Wavelet coefficient vectors.}
  \item{s?}{Scaling coefficient vector.}
  \item{wavelet}{Name of the wavelet filter used.}
  \item{boundary}{How the boundaries were handled.}
}
\details{
  The code implements the one-dimensional non-decimated DWT using the
  pyramid algorithm.  The actual transform is performed in C using
  pseudocode from Percival and Walden (2001).  That means convolutions,
  not inner products, are used to apply the wavelet filters.

  The MODWT goes by several names in the statistical and engineering
  literature, such as, the ``stationary DWT'', ``translation-invariant
  DWT'', and ``time-invariant DWT''.

  The inverse MODWT implements the one-dimensional inverse transform
  using the pyramid algorithm (Mallat, 1989). 
}
\references{
  Gencay, R., F. Selcuk and B. Whitcher (2001)
  \emph{An Introduction to Wavelets and Other Filtering Methods in
    Finance and Economics},
  Academic Press.
  
  Percival, D. B. and P. Guttorp (1994)
  Long-memory processes, the Allan variance and wavelets,
  In \emph{Wavelets and Geophysics}, pages 325-344, Academic Press.

  Percival, D. B. and A. T. Walden (2000)
  \emph{Wavelet Methods for Time Series Analysis},
  Cambridge University Press.
}
\seealso{
  \code{\link{dwt}}, \code{\link{idwt}}, \code{\link{mra}}.
}
\examples{
## Figure 4.23 in Gencay, Selcuk and Whitcher (2001)
data(ibm)     
ibm.returns <- diff(log(ibm))
# Haar
ibmr.haar <- modwt(ibm.returns, "haar")
names(ibmr.haar) <- c("w1", "w2", "w3", "w4", "v4")
# LA(8)
ibmr.la8 <- modwt(ibm.returns, "la8")
names(ibmr.la8) <- c("w1", "w2", "w3", "w4", "v4")
# shift the MODWT vectors
ibmr.la8 <- phase.shift(ibmr.la8, "la8")
## plot partial MODWT for IBM data
par(mfcol=c(6,1), pty="m", mar=c(5-2,4,4-2,2))
plot.ts(ibm.returns, axes=FALSE, ylab="", main="(a)")
for(i in 1:5)
  plot.ts(ibmr.haar[[i]], axes=FALSE, ylab=names(ibmr.haar)[i])
axis(side=1, at=seq(0,368,by=23), 
  labels=c(0,"",46,"",92,"",138,"",184,"",230,"",276,"",322,"",368))
par(mfcol=c(6,1), pty="m", mar=c(5-2,4,4-2,2))
plot.ts(ibm.returns, axes=FALSE, ylab="", main="(b)")
for(i in 1:5)
  plot.ts(ibmr.la8[[i]], axes=FALSE, ylab=names(ibmr.la8)[i])
axis(side=1, at=seq(0,368,by=23), 
  labels=c(0,"",46,"",92,"",138,"",184,"",230,"",276,"",322,"",368))
}
\author{B. Whitcher}
\keyword{ts}

\eof
\name{mra.2d}
\alias{mra.2d}
\title{Multiresolution Analysis of an Image}
\description{
  This function performs a level \eqn{J} additive decomposition of the
  input matrix or image using the pyramid algorithm (Mallat 1989).
}
\usage{mra.2d(x, wf = "la8", J = 4, method = "modwt", boundary = "periodic")
}
\arguments{
  \item{x}{A matrix or image containing the data be to decomposed.  This
    must be have dyadic length in both dimensions (but not necessarily
    the same) for \code{method="dwt"}.}
  \item{wf}{Name of the wavelet filter to use in the decomposition.  By
    default this is set to \code{"la8"}, the Daubechies orthonormal
    compactly supported wavelet of length \eqn{L=8} least asymmetric
    family.}
  \item{J}{Specifies the depth of the decomposition.  This must be a
    number less than or equal to
    \eqn{\log(\mbox{length}(x),2)}{log(length(x),2)}.}
  \item{method}{Either \code{"dwt"} or \code{"modwt"}.}
  \item{boundary}{Character string specifying the boundary condition.
    If \code{boundary=="periodic"} the default, then the matrix you
    decompose is assumed to be periodic on its defined interval,\cr
    if \code{boundary=="reflection"}, the matrix beyond its boundaries
    is assumed to be a symmetric reflection of itself.}
}
\value{
  Basically, a list with the following components
  \item{LH?}{Wavelet detail image in the horizontal direction.}
  \item{HL?}{Wavelet detail image in the vertical direction.}
  \item{HH?}{Wavelet detail image in the diagonal direction.}
  \item{LL\eqn{J}}{Wavelet smooth image at the coarsest resolution.}
  \item{\eqn{J}}{Depth of the wavelet transform.}
  \item{wavelet}{Name of the wavelet filter used.}
  \item{boundary}{How the boundaries were handled.}
}
\details{
  This code implements a two-dimensional multiresolution analysis
  by performing the one-dimensional pyramid algorithm (Mallat 1989) on
  the rows and columns of the input matrix.  Either the DWT or MODWT may
  be used to compute the multiresolution analysis, which is an additive
  decomposition of the original matrix (image).
}
\references{
  Mallat, S. G. (1989)
  A theory for multiresolution signal decomposition: the wavelet
  representation,
  \emph{IEEE Transactions on Pattern Analysis and Machine Intelligence},
  \bold{11}, No. 7, 674-693.

  Mallat, S. G. (1998)
  \emph{A Wavelet Tour of Signal Processing},
  Academic Press.
}
\seealso{
  \code{\link{dwt.2d}}, \code{\link{modwt.2d}}
}
\author{B. Whitcher}
\examples{
## Easy check to see if it works...
## --------------------------------

x <- matrix(rnorm(32*32), 32, 32)
# MODWT
x.mra <- mra.2d(x, method="modwt")
x.mra.sum <- x.mra[[1]]
for(j in 2:length(x.mra))
  x.mra.sum <- x.mra.sum + x.mra[[j]]
sum((x - x.mra.sum)^2)

# DWT
x.mra <- mra.2d(x, method="dwt")
x.mra.sum <- x.mra[[1]]
for(j in 2:length(x.mra))
  x.mra.sum <- x.mra.sum + x.mra[[j]]
sum((x - x.mra.sum)^2)
}
\keyword{ts}

\eof
\name{mra.3d}
\alias{mra.3d}
\title{Three Dimensional Multiresolution Analysis}
\description{
  This function performs a level \eqn{J} additive decomposition of the
  input array using the pyramid algorithm (Mallat 1989).
}
\usage{mra.3d(x, wf, J=4, method="modwt", boundary="periodic")
}
\arguments{
  \item{x}{A three-dimensional array containing the data be to
    decomposed.  This must be have dyadic length in all three dimensions
    (but not necessarily the same) for \code{method="dwt"}.}
  \item{wf}{Name of the wavelet filter to use in the decomposition.  By
    default this is set to \code{"la8"}, the Daubechies orthonormal
    compactly supported wavelet of length \eqn{L=8} least asymmetric
    family.}
  \item{J}{Specifies the depth of the decomposition.  This must be a
    number less than or equal to
    \eqn{\log(\mbox{length}(x),2)}{log(length(x),2)}.}
  \item{method}{Either \code{"dwt"} or \code{"modwt"}.}
  \item{boundary}{Character string specifying the boundary condition.
    If \code{boundary=="periodic"} the default and only method
    implemented, then the matrix you decompose is assumed to be periodic
    on its defined interval.}
}
\value{
}
\details{
  This code implements a three-dimensional multiresolution analysis
  by performing the one-dimensional pyramid algorithm (Mallat 1989) on
  each dimension of the input array.  Either the DWT or MODWT may be
  used to compute the multiresolution analysis, which is an additive 
  decomposition of the original array.
}
\references{
  Mallat, S. G. (1989)
  A theory for multiresolution signal decomposition: the wavelet
  representation,
  \emph{IEEE Transactions on Pattern Analysis and Machine Intelligence},
  \bold{11}, No. 7, 674-693.

  Mallat, S. G. (1998)
  \emph{A Wavelet Tour of Signal Processing},
  Academic Press.
}
\seealso{
  \code{\link{dwt.3d}}, \code{\link{modwt.3d}}
}
%\examples{}
\author{B. Whitcher}
\keyword{ts}

\eof
\name{mra}
\alias{mra}
\title{Multiresolution Analysis of Time Series}
\description{
  This function performs a level \eqn{J} additive decomposition of the
  input vector or time series using the pyramid algorithm (Mallat 1989).
}
\usage{mra(x, wf = "la8", J = 4, method = "modwt", boundary = "periodic")
}
\arguments{
  \item{x}{A vector or time series containing the data be to
    decomposed.  This must be a dyadic length vector (power of 2) for
    \code{method="dwt"}.}
  \item{wf}{Name of the wavelet filter to use in the decomposition.  By
    default this is set to \code{"la8"}, the Daubechies orthonormal
    compactly supported wavelet of length \eqn{L=8} least asymmetric
    family.}
  \item{J}{Specifies the depth of the decomposition.  This must be a
    number less than or equal to
    \eqn{\log(\mbox{length}(x),2)}{log(length(x),2)}.}
  \item{method}{Either \code{"dwt"} or \code{"modwt"}.}
  \item{boundary}{Character string specifying the boundary condition.
    If \code{boundary=="periodic"} the default, then the vector you
    decompose is assumed to be periodic on its defined interval,\cr
    if \code{boundary=="reflection"}, the vector beyond its boundaries
    is assumed to be a symmetric reflection of itself.}
}
\value{
  Basically, a list with the following components
  \item{D?}{Wavelet detail vectors.}
  \item{S?}{Wavelet smooth  vector.}
  \item{wavelet}{Name of the wavelet filter used.}
  \item{boundary}{How the boundaries were handled.}
}
\details{
  This code implements a one-dimensional multiresolution analysis
  introduced by Mallat (1989).  Either the DWT or MODWT may be used to
  compute the multiresolution analysis, which is an additive
  decomposition of the original time series.
}
\references{
  Gencay, R., F. Selcuk and B. Whitcher (2001)
  \emph{An Introduction to Wavelets and Other Filtering Methods in
    Finance and Economics},
  Academic Press.
  
  Mallat, S. G. (1989)
  A theory for multiresolution signal decomposition: the wavelet
  representation,
  \emph{IEEE Transactions on Pattern Analysis and Machine Intelligence},
  \bold{11}, No. 7, 674-693.

  Percival, D. B. and A. T. Walden (2000)
  \emph{Wavelet Methods for Time Series Analysis},
  Cambridge University Press.
}
\seealso{
  \code{\link{dwt}}, \code{\link{modwt}}.
}
\examples{
## Easy check to see if it works...
x <- rnorm(32)
x.mra <- mra(x)
sum(x - apply(matrix(unlist(x.mra), nrow=32), 1, sum))^2

## Figure 4.19 in Gencay, Selcuk and Whitcher (2001)
data(ibm)     
ibm.returns <- diff(log(ibm))
ibm.volatility <- abs(ibm.returns)
## Haar
ibmv.haar <- mra(ibm.volatility, "haar", 4, "dwt")
names(ibmv.haar) <- c("d1", "d2", "d3", "d4", "s4")
## LA(8)
ibmv.la8 <- mra(ibm.volatility, "la8", 4, "dwt")
names(ibmv.la8) <- c("d1", "d2", "d3", "d4", "s4")
## plot multiresolution analysis of IBM data
par(mfcol=c(6,1), pty="m", mar=c(5-2,4,4-2,2))
plot.ts(ibm.volatility, axes=FALSE, ylab="", main="(a)")
for(i in 1:5)
  plot.ts(ibmv.haar[[i]], axes=FALSE, ylab=names(ibmv.haar)[i])
axis(side=1, at=seq(0,368,by=23), 
  labels=c(0,"",46,"",92,"",138,"",184,"",230,"",276,"",322,"",368))
par(mfcol=c(6,1), pty="m", mar=c(5-2,4,4-2,2))
plot.ts(ibm.volatility, axes=FALSE, ylab="", main="(b)")
for(i in 1:5)
  plot.ts(ibmv.la8[[i]], axes=FALSE, ylab=names(ibmv.la8)[i])
axis(side=1, at=seq(0,368,by=23), 
  labels=c(0,"",46,"",92,"",138,"",184,"",230,"",276,"",322,"",368))
}
\author{B. Whitcher}
\keyword{ts}

\eof
\name{mult.loc}
\alias{mult.loc}
\title{Wavelet-based Testing and Locating for Variance Change Points}
\description{
  This is the major subroutine for \code{\link{testing.hov}}, providing
  the workhorse algorithm to recursively test and locate multiple
  variance changes in so-called long memory processes.
}
\usage{mult.loc(dwt.list, modwt.list, wf, level, min.coef, debug)
}
\arguments{
  \item{dwt.list}{}
  \item{modwt.list}{}
  \item{wf}{
    Name of the wavelet filter to use in the decomposition.
  }
  \item{level}{
    Specifies the depth of the decomposition.
  }
  \item{min.coef}{
    Minimum number of wavelet coefficients for testing purposes.
  }
  \item{debug}{
    Boolean variable: if set to \code{TRUE}, actions taken by
    the algorithm are printed to the screen.
  }  
}
\value{
  Matrix.
}
\details{
  For details see Section 9.6 of Percival and Walden (2000) or Section
  7.3 in Gencay, Selcuk and Whitcher (2001).
}
\references{
  Gencay, R., F. Selcuk and B. Whitcher (2001)
  \emph{An Introduction to Wavelets and Other Filtering Methods in
    Finance and Economics},
  Academic Press.
  
  Percival, D. B. and A. T. Walden (2000)
  \emph{Wavelet Methods for Time Series Analysis},
  Cambridge University Press.
}
\seealso{
  \code{\link{rotcumvar}}, \code{\link{testing.hov}}.
}
%\examples{}
\author{B. Whitcher}
\keyword{ts}

\eof
\name{my.acf}
\alias{my.acf}
\alias{my.ccf}
\title{Autocovariance Functions via the Discrete Fourier Transform}
\description{
  Computes the autocovariance function (ACF) for a time series or the
  cross-covariance function (CCF) between two time series.
}
\usage{my.acf(x)
my.ccf(a, b)
}
\arguments{
  \item{x,a,b}{time series}
}
\value{
  The autocovariance function for all nonnegative lags or the
  cross-covariance function for all lags.
}
\details{
  The series is zero padded to twice its length before the discrete
  Fourier transform is applied.  Only the values corresponding to
  nonnegative lags are provided (for the ACF).
}
%\references{}
%\seealso{}
\examples{
data(ibm)
ibm.returns <- diff(log(ibm))
plot(1:length(ibm.returns) - 1, my.acf(ibm.returns), type="h",
     xlab="lag", ylab="ACVS", main="Autocovariance Sequence for IBM Returns")
}
\author{B. Whitcher}
\keyword{ts}

\eof
\name{nile}
\alias{nile}
\title{Nile River Minima}
\description{
  Yearly minimal water levels of the Nile river for the years 622 to
  1281, measured at the Roda gauge near Cairo (Tousson, 1925,
  p. 366-385). The data are listed in chronological sequence by row.

  The original Nile river data supplied by Beran only contained only 500
  observations (622 to 1121).  However, the book claimed to have 660
  observations (622 to 1281).  The remaining observations from the book
  were added, by hand, but the series still only contained 653
  observations (622 to 1264).

  Note, now the data consists of 663 observations (spanning the years
  622-1284) as in original source (Toussoun, 1925).
}
\usage{data(nile)
}
\format{A length 663 vector.
}
\source{
  Toussoun, O. (1925)
  {M}{\'e}moire sur l'Histoire du {N}il,
  Volume 18 in \emph{M{\'e}moires a l'Institut d'Egypte},
  pp. 366-404.
}
\references{
  Beran, J. (1994)
  \emph{Statistics for Long-Memory Processes}, Chapman Hall: Englewood, NJ.
}
\keyword{datasets}

\eof
\name{ortho.basis}
\alias{ortho.basis}
\title{Derive Orthonormal Basis from Wavelet Packet Tree}
\description{
  An orthonormal basis for the discrete wavelet transform may be
  characterized via a disjoint partitioning of the frequency axis that
  covers \eqn{[0,\frac{1}{2})}{[0,1/2)}.  This subroutine produces an
  orthonormal basis from a full wavelet packet tree.
}
\usage{ortho.basis(xtree)
}
\arguments{
  \item{xtree}{is a vector whose entries are associated with a wavelet
    packet tree.}
}
\value{
  Boolean vector describing the orthonormal basis for the DWPT.
}
\details{
  A wavelet packet tree is a binary tree of Boolean variables.  Parent
  nodes are removed if any of their children exist.
}
%\references{}
%\seealso{}
\examples{
data(japan)
J <- 4
wf <- "mb8"
japan.mra <- mra(log(japan), wf, J, boundary="reflection")
japan.nomean <-
  ts(apply(matrix(unlist(japan.mra[-(J+1)]), ncol=J, byrow=FALSE), 1, sum),
     start=1955, freq=4)
japan.nomean2 <- ts(japan.nomean[42:169], start=1965.25, freq=4)
plot.ts(japan.nomean2)
japan.dwpt <- dwpt(japan.nomean2, wf, 6)
japan.basis <-
  ortho.basis(portmanteau.test(japan.dwpt, p=0.01, type="other"))
# Not implemented yet
# par(mfrow=c(1,1))
# plot.basis(japan.basis)
}
\author{B. Whitcher}
\keyword{ts}

\eof
\name{phase.shift}
\alias{phase.shift}
\alias{phase.shift.packet}
\title{Phase Shift Wavelet Coefficients}
\description{
  Wavelet coefficients are circularly shifted by the amount of phase
  shift induced by the wavelet transform.
}
\usage{phase.shift(z, wf, inv = FALSE)
phase.shift.packet(z, wf, inv = FALSE)
}
\arguments{
  \item{z}{DWT object}
  \item{wf}{character string; wavelet filter used in DWT}
  \item{inv}{Boolean variable; if \code{inv=TRUE} then the inverse phase
    shift is applied}
}
\value{
  DWT (DWPT) object with coefficients circularly shifted.
}
\details{
  The center-of-energy argument of Hess-Nielsen and Wickerhauser (1996)
  is used to provide a flexible way to circularly shift wavelet
  coefficients regardless of the wavelet filter used.  The results are
  not identical to those used by Percival and Walden (2000), but are
  more flexible.

  \code{phase.shift.packet} is not yet implemented fully.
}
\references{
  Hess-Nielsen, N. and M. V. Wickerhauser (1996)
  Wavelets and time-frequency analysis,
  \emph{Proceedings of the IEEE}, \bold{84}, No. 4, 523-540.
  
  Percival, D. B. and A. T. Walden (2000)
  \emph{Wavelet Methods for Time Series Analysis},
  Cambridge University Press.
}
%\seealso{}
%\examples{}
\author{B. Whitcher}
\keyword{ts}

\eof
\name{phase.shift.hilbert}
\alias{phase.shift.hilbert}
\alias{phase.shift.hilbert.packet}
\title{Phase Shift for Hilbert Wavelet Coefficients}
\description{
  Wavelet coefficients are circularly shifted by the amount of phase
  shift induced by the discrete Hilbert wavelet transform.
}
\usage{
phase.shift.hilbert(x, wf)
phase.shift.hilbert.packet(x, wf)
}
\arguments{
  \item{x}{Discete Hilbert wavelet transform (DHWT) object.}
  \item{wf}{character string; Hilbert wavelet pair used in DHWT}
}
\value{
  DHWT (DHWPT) object with coefficients circularly shifted.
}
\details{
  The "center-of-energy" argument of Hess-Nielsen and Wickerhauser
  (1996) is used to provide a flexible way to circularly shift wavelet 
  coefficients regardless of the wavelet filter used.
}
\references{
  Hess-Nielsen, N. and M. V. Wickerhauser (1996)
  Wavelets and time-frequency analysis,
  \emph{Proceedings of the IEEE}, \bold{84}, No. 4, 523-540.
}
\seealso{
  \code{\link{phase.shift}}
}
%\examples{}
\author{B. Whitcher}
\keyword{ts}

\eof
\name{plot.dwt.2d}
\alias{plot.dwt.2d}
\title{Plot Two-dimensional Discrete Wavelet Transform}
\description{
  Organizes the wavelet coefficients from a 2D DWT into a single matrix
  and plots it.  The coarser resolutions are nested within the
  lower-lefthand corner of the image.
}
\usage{plot.dwt.2d(x, cex.axis = 1, plot = TRUE, ...)
}
\arguments{
  \item{x}{input matrix (image)}
  \item{cex.axis}{\code{par} plotting parameter that controls the size
    of the axis text}
  \item{plot}{if \code{plot = FALSE} then the matrix of wavelet
    coefficients is returned, the default is \code{plot = TRUE}}
  \item{...}{additional graphical parameters if necessary}
}
\value{
  Image plot.
}
\details{
  The wavelet coefficients from the DWT object (a list) are reorganized
  into a single matrix of the same dimension as the original image and
  the result is plotted.
}
%\references{}
\seealso{
  \code{\link{dwt.2d}}.
}
%\examples{}
\author{B. Whitcher}
\keyword{ts}

\eof
\name{qmf}
\alias{qmf}
\title{Quadrature Mirror Filter}
\description{
  Computes the quadrature mirror filter from a given filter.
}
\usage{qmf(g, low2high=TRUE)
}
\arguments{
  \item{g}{Filter coefficients.}
  \item{low2high}{Logical, default is \code{TRUE} which means a low-pass
    filter is input and a high-pass filter is output.  Setting
    \code{low2high=F} performs the inverse.}
}
\value{
  Quadrature mirror filter.
}
\details{
  None.
}
\references{
  Any basic signal processing text.
}
\seealso{
  \code{\link{wave.filter}}.
}
\examples{
## Haar wavelet filter
g <- wave.filter("haar")$lpf
qmf(g)
}
\author{B. Whitcher}
\keyword{ts}

\eof
\name{rotcumvar}
\alias{rotcumvar}
\title{Rotated Cumulative Variance}
\description{
  Provides the normalized cumulative sums of squares from a sequence of
  coefficients with the diagonal line removed.
}
\usage{rotcumvar(x)
}
\arguments{
  \item{x}{vector of coefficients to be cumulatively summed (missing
    values excluded)}
}
\value{Vector of coefficients that are the sumulative sum of squared
  input coefficients.
}
\details{
  The rotated cumulative variance, when plotted, provides a qualitative
  way to study the time dependence of the variance of a series.  If the
  variance is stationary over time, then only small deviations from zero
  should be present.  If on the other hand the variance is
  non-stationary, then large departures may exist.  Formal hypothesis
  testing may be performed based on boundary crossings of Brownian
  bridge processes.
}
\references{
  Gencay, R., F. Selcuk and B. Whitcher (2001)
  \emph{An Introduction to Wavelets and Other Filtering Methods in
    Finance and Economics},
  Academic Press.
  
  Percival, D. B. and A. T. Walden (2000)
  \emph{Wavelet Methods for Time Series Analysis},
  Cambridge University Press.
}
%\seealso{}
%\examples{}
\author{B. Whitcher}
\keyword{ts}

\eof
\name{Spectral Density Functions}
\alias{fdp.sdf}
\alias{spp.sdf}
\alias{spp2.sdf}
\alias{sfd.sdf}
\title{Spectral Density Functions for Long-Memory Processes}
\description{
  Draws the spectral density functions (SDFs) for standard long-memory
  processes including fractional difference (FD), seasonal persistent
  (SP), and seasonal fractional difference (SFD) processes.
}
\usage{fdp.sdf(freq, d, sigma2 = 1)
spp.sdf(freq, d, fG, sigma2 = 1)
spp2.sdf(freq, d1, f1, d2, f2, sigma2 = 1)
sfd.sdf(freq, s, d, sigma2 = 1)
}
\arguments{
  \item{freq}{vector of frequencies, normally from 0 to 0.5}
  \item{d,d1,d2}{fractional difference parameter}
  \item{fG,f1,f2}{Gegenbauer frequency}
  \item{s}{seasonal parameter}
  \item{sigma2}{innovations variance}
}
\value{
  The power spectrum from an FD, SP or SFD process.
}
\details{
}
%\references{}
\seealso{
  \code{\link{fdp.mle}}, \code{\link{spp.mle}}.
}
\examples{
dB <- function(x) 10 * log10(x)

fdp.main <- expression(paste("FD", group("(",d==0.4,")")))
sfd.main <- expression(paste("SFD", group("(",list(s==12, d==0.4),")")))
spp.main <- expression(paste("SPP",
    group("(",list(delta==0.4, f[G]==1/12),")")))

freq <- 0:512/1024

par(mfrow=c(2,2), mar=c(5-1,4,4-1,2), col.main="darkred")
plot(freq, dB(fdp.sdf(freq, .4)), type="l", xlab="frequency",
     ylab="spectrum (dB)", main=fdp.main)
plot(freq, dB(spp.sdf(freq, .4, 1/12)), type="l", xlab="frequency",
     ylab="spectrum (dB)", font.main=1, main=spp.main)
plot(freq, dB(sfd.sdf(freq, 12, .4)), type="l", xlab="frequency",
     ylab="spectrum (dB)", main=sfd.main)
}
\author{B. Whitcher}
\keyword{ts}

\eof
\name{shift.2d}
\alias{shift.2d}
\title{Circularly Shift Matrices from a 2D MODWT}
\description{
  Compute phase shifts for wavelet sub-matrices based on the ``center of
  energy'' argument of Hess-Nielsen and Wickerhauser (1996).
}
\usage{shift.2d(z, wf, inv=FALSE)
}
\arguments{
  \item{z}{2D MODWT object}
  \item{wf}{Character string for wavelet filter.}
  \item{inv}{Boolean value on whether to perform the forward or inverse
    operation.}
}
\value{
  2D MODWT object with circularly shifted coefficients.
}
\details{
  The "center of energy" technique of Wickerhauser and Hess-Nielsen
  (1996) is employed to find circular shifts for the wavelet
  sub-matrices such that the coefficients are aligned with the original
  series.  This corresponds to applying a (near) linear-phase filtering
  operation.
}
\references{
  Hess-Nielsen, N. and M. V. Wickerhauser (1996)
  Wavelets and time-frequency analysis,
  \emph{Proceedings of the IEEE}, \bold{84}, No. 4, 523-540.
  
  Percival, D. B. and A. T. Walden (2000)
  \emph{Wavelet Methods for Time Series Analysis},
  Cambridge University Press.
}
\seealso{
  \code{\link{phase.shift}}, \code{\link{modwt.2d}}.
}
\examples{
G1 <- G2 <- dnorm(seq(-512/4,512/4,length=512))
G <- 100 * zapsmall(G1 \%o\% G2)
J <- 6
G <- modwt.2d(G, "la8", J)
names.modwt <- c(t(sapply(c("LH","HL","HH"), paste, 1:J, sep="")), 
                 paste("LL", J, sep=""))
n <- 50
par(mfrow=c(3,3), mar=c(5,4,4,2)/1.9, pty="s")
for(i in names.modwt[1:9])
  image(G[[i]][256 + -n:n, 256 + -n:n], axes=FALSE, col=rainbow(128), main=i)
Gs <- shift.2d(G, "la8")
for(i in names.modwt[1:9])
  image(Gs[[i]][256 + -n:n, 256 + -n:n], axes=FALSE, col=rainbow(128), main=i)
}
\author{B. Whitcher}
\keyword{ts}

\eof
\name{sine.taper}
\alias{sine.taper}
\title{Computing Sinusoidal Data Tapers}
\description{
  Computes sinusoidal data tapers directly from equations.
}
\usage{sine.taper(n, k)
}
\arguments{
  \item{n}{length of data taper(s)}
  \item{k}{number of data tapers}
}
\value{
  A vector or matrix of data tapers (cols = tapers).
}
\details{
  See reference.
}
\references{
  Riedel, K. S. and A. Sidorenko (1995)
  Minimum bias multiple taper spectral estimation,
  \emph{IEEE Transactions on Signal Processing}, \bold{43}, 188-195.
}
\seealso{
  \code{\link{dpss.taper}}.
}
%\examples{}
\author{B. Whitcher}
\keyword{ts}

\eof
\name{spin.covariance}
\alias{spin.covariance}
\alias{spin.correlation}
\title{Compute Wavelet Cross-Covariance Between Two Time Series}
\description{
  Computes wavelet cross-covariance or cross-correlation between two
  time series.
}
\usage{spin.covariance(x, y, lag.max = NA)
spin.correlation(x, y, lag.max = NA)
}
\arguments{
  \item{x}{first time series}
  \item{y}{second time series, same length as \code{x}}
  \item{lag.max}{maximum lag to compute cross-covariance (correlation)}
}
\value{
  List structure holding the wavelet cross-covariances (correlations)
  according to scale.
}
\details{
  See references.
}
\references{
  Gencay, R., F. Selcuk and B. Whitcher (2001)
  \emph{An Introduction to Wavelets and Other Filtering Methods in
    Finance and Economics},
  Academic Press.

  Whitcher, B., P. Guttorp and D. B. Percival (2000)
  Wavelet analysis of covariance with application to atmospheric time
  series,
  \emph{Journal of Geophysical Research}, \bold{105}, No. D11,
  14,941-14,962.
}
\seealso{
  \code{\link{wave.covariance}}, \code{\link{wave.correlation}}.
}
\examples{
## Figure 7.9 from Gencay, Selcuk and Whitcher (2001)
data(exchange)
returns <- diff(log(exchange))
returns <- ts(returns, start=1970, freq=12)
wf <- "d4"
demusd.modwt <- modwt(returns[,"DEM.USD"], wf, 8)
demusd.modwt.bw <- brick.wall(demusd.modwt, wf)
jpyusd.modwt <- modwt(returns[,"JPY.USD"], wf, 8)
jpyusd.modwt.bw <- brick.wall(jpyusd.modwt, wf)
n <- dim(returns)[1]
J <- 6
lmax <- 36
returns.cross.cor <- NULL
for(i in 1:J) {
  blah <- spin.correlation(demusd.modwt.bw[[i]], jpyusd.modwt.bw[[i]], lmax)
  returns.cross.cor <- cbind(returns.cross.cor, blah)
}
returns.cross.cor <- ts(as.matrix(returns.cross.cor), start=-36, freq=1)
dimnames(returns.cross.cor) <- list(NULL, paste("Level", 1:J))
lags <- length(-lmax:lmax)
lower.ci <- tanh(atanh(returns.cross.cor) - qnorm(0.975) /
                 sqrt(matrix(trunc(n/2^(1:J)), nrow=lags, ncol=J, byrow=TRUE)
                      - 3))
upper.ci <- tanh(atanh(returns.cross.cor) + qnorm(0.975) /
                 sqrt(matrix(trunc(n/2^(1:J)), nrow=lags, ncol=J, byrow=TRUE)
                      - 3))
par(mfrow=c(3,2), las=1, pty="m", mar=c(5,4,4,2)+.1)
for(i in J:1) {
  plot(returns.cross.cor[,i], ylim=c(-1,1), xaxt="n", xlab="Lag (months)",
       ylab="", main=dimnames(returns.cross.cor)[[2]][i])
  axis(side=1, at=seq(-36, 36, by=12))
  lines(lower.ci[,i], lty=1, col=2)
  lines(upper.ci[,i], lty=1, col=2)
  abline(h=0,v=0)
}
}
\author{B. Whitcher}
\keyword{ts}

\eof
\name{spp.mle}
\alias{spp.mle}
\alias{spp2.mle}
\title{Wavelet-based Maximum Likelihood Estimation for Seasonal
  Persistent Processes}
\description{
  Parameter estimation for a seasonal persistent (seasonal long-memory)
  process is performed via maximum likelihood on the wavelet
  coefficients.
}
\usage{spp.mle(y, wf, J=log(length(y),2)-1, p=0.01, frac=1)
spp2.mle(y, wf, J=log(length(y),2)-1, p=0.01, dyadic=TRUE, frac=1)
}
\arguments{
  \item{y}{Not necessarily dyadic length time series.}
  \item{wf}{Name of the wavelet filter to use in the decomposition.  See
    \code{\link{wave.filter}} for those wavelet filters available.}
  \item{J}{Depth of the discrete wavelet packet transform.}
  \item{p}{Level of significance for the white noise testing procedure.}
  \item{dyadic}{Logical parameter indicating whether or not the original
    time series is dyadic in length.}
  \item{frac}{Fraction of the time series that should be used in
    constructing the likelihood function.}
}
\value{
  List containing the maximum likelihood estimates (MLEs) of
  \eqn{\delta}, \eqn{f_G} and \eqn{\sigma^2}, along with the value of
  the likelihood for those estimates.
}
\details{
  The variance-covariance matrix of the original time series is
  approximated by its wavelet-based equivalent.  A Whittle-type
  likelihood is then constructed where the sums of squared wavelet
  coefficients are compared to bandpass filtered version of the true
  spectral density function.  Minimization occurs for the fractional
  difference parameter \eqn{d} and the Gegenbauer frequency \eqn{f_G},
  while the innovations variance is subsequently estimated.
}
\references{
  Whitcher, B. (2003)
  Wavelet-based estimation for seasonal long-memory processes.
  Technical Report.
}
\seealso{
  \code{\link{fdp.mle}}
}
%\examples{}
\author{B. Whitcher}
\keyword{ts}

\eof
\name{spp.var}
\alias{spp.var}
\alias{Hypergeometric}
\title{Variance of a Seasonal Persistent Process}
\description{
  Computes the variance of a seasonal persistent (SP) process using a
  hypergeometric series expansion.
}
\usage{
spp.var(d, fG, sigma2 = 1)
Hypergeometric(a, b, c, z)
}
\arguments{
  \item{d}{Fractional difference parameter.}
  \item{fG}{Gegenbauer frequency.}
  \item{sigma2}{Innovations variance.}
  \item{a,b,c,z}{Parameters for the hypergeometric series.}
}
\value{
  The variance of an SP process.
}
\details{
  See Lapsa (1997).  The subroutine to compute a hypergeometric series
  was taken from \emph{Numerical Recipes in C}.
}
\references{
  Lapsa, P.M. (1997)
  Determination of Gegenbauer-type random process models.
  \emph{Signal Processing} \bold{63}, 73-90.

  Press, W.H., S.A. Teukolsky, W.T. Vetterling and B.P. Flannery (1992)
  \emph{Numerical Recipes in C}, 2nd edition,
  Cambridge University Press.
}
%\seealso{}
%\examples{}
\author{B. Whitcher}
\keyword{ts}

\eof
\name{squared.gain}
\alias{squared.gain}
\title{Squared Gain Function of a Filter}
\description{
  Produces the modulus squared of the Fourier transform for a given
  filtering sequence.
}
\usage{squared.gain(wf.name, filter.seq = "L", n = 512) 
}
\arguments{
  \item{wf.name}{Character string of wavelet filter.}
  \item{filter.seq}{Character string of filter sequence.  \code{H} means
    high-pass filtering and \code{L} means low-pass filtering.  Sequence
    is read from right to left.}
  \item{n}{Length of zero-padded filter.  Frequency resolution will be
    \code{n}/2+1.}
}
\value{
  Squared gain function.
}
\details{
  Uses \code{cascade} subroutine to compute the squared gain function
  from a given filtering sequence.
}
%\references{}
\seealso{
  \code{\link{wave.filter}}, \code{\link{wavelet.filter}}.
}
\examples{
par(mfrow=c(2,2))
f.seq <- "H"
plot(0:256/512, squared.gain("d4", f.seq), type="l", ylim=c(0,2),
     xlab="frequency", ylab="L = 4", main="Level 1")
lines(0:256/512, squared.gain("fk4", f.seq), col=2)
lines(0:256/512, squared.gain("mb4", f.seq), col=3)
abline(v=c(1,2)/4, lty=2)
legend(-.02, 2, c("Daubechies", "Fejer-Korovkin", "Minimum-Bandwidth"),
       lty=1, col=1:3, bty="n", cex=1)
f.seq <- "HL"
plot(0:256/512, squared.gain("d4", f.seq), type="l", ylim=c(0,4),
     xlab="frequency", ylab="", main="Level 2")
lines(0:256/512, squared.gain("fk4", f.seq), col=2)
lines(0:256/512, squared.gain("mb4", f.seq), col=3)
abline(v=c(1,2)/8, lty=2)
f.seq <- "H"
plot(0:256/512, squared.gain("d8", f.seq), type="l", ylim=c(0,2),
     xlab="frequency", ylab="L = 8", main="")
lines(0:256/512, squared.gain("fk8", f.seq), col=2)
lines(0:256/512, squared.gain("mb8", f.seq), col=3)
abline(v=c(1,2)/4, lty=2)
f.seq <- "HL"
plot(0:256/512, squared.gain("d8", f.seq), type="l", ylim=c(0,4),
     xlab="frequency", ylab="", main="")
lines(0:256/512, squared.gain("fk8", f.seq), col=2)
lines(0:256/512, squared.gain("mb8", f.seq), col=3)
abline(v=c(1,2)/8, lty=2)
}
\author{B. Whitcher}
\keyword{ts}

\eof
\name{stack.plot}
\alias{stack.plot}
\title{Stack Plot}
\description{
  Stack plot of an object.  This function attempts to mimic a function
  of the same name in S+WAVELETS.  It is mostly a hacked version of
  \code{plot.ts} in \R.
}
\usage{stack.plot(x, plot.type = c("multiple", "single"), panel = lines, 
    log = "", col = par("col"), bg = NA, pch = par("pch"), cex = par("cex"),
    lty = par("lty"), lwd = par("lwd"), ann = par("ann"), xlab = "Time",
    main = NULL, oma = c(6, 0, 5, 0), layout = NULL,
    same.scale = 1:dim(x)[2], ...)
}
\arguments{
  \item{x}{\code{ts} object}
  \item{layout}{Doublet defining the dimension of the panel.  If not
    specified, the dimensions are chosen automatically.}
  \item{same.scale}{Vector the same length as the number of series to be
    plotted.  If not specified, all panels will have unique axes.}
  \item{plot.type,panel,log,col,bg,pch,cex,lty,lwd,ann,xlab,main,oma,...}{See \code{plot.ts}.}
}
\value{
}
\details{
  Produces a set of plots, one for each element (column) of \code{x}.
}
\references{
  
}
\seealso{}
%\examples{}
\keyword{hplot}

\eof
\name{testing.hov}
\alias{testing.hov}
\title{Testing for Homogeneity of Variance}
\description{
  A recursive algorithm for detecting and locating multiple variance
  change points in a sequence of random variables with long-range
  dependence.
}
\usage{testing.hov(x, wf, J, min.coef=128, debug=FALSE)
}
\arguments{
  \item{x}{
    Sequence of observations from a (long memory) time series.
  }
  \item{wf}{
    Name of the wavelet filter to use in the decomposition.
  }
  \item{J}{
    Specifies the depth of the decomposition.  This must be a number
    less than or equal to
    \eqn{\log(\mbox{length}(x),2)}{log(length(x),2)}.
  }
  \item{min.coef}{
    Minimum number of wavelet coefficients for testing purposes.
    Empirical results suggest that 128 is a reasonable number in order
    to apply asymptotic critical values.
  } 
  \item{debug}{
    Boolean variable: if set to \code{TRUE}, actions taken by
    the algorithm are printed to the screen.
  }
}
\value{
  Matrix whose columns include (1) the level of the wavelet transform
  where the variance change occurs, (2) the value of the test statistic,
  (3) the DWT coefficient where the change point is located, (4) the
  MODWT coefficient where the change point is located.  Note, there is
  currently no checking that the MODWT is contained within the
  associated support of the DWT coefficient.  This could lead to
  incorrect estimates of the location of the variance change.
}
\details{
  For details see Section 9.6 of Percival and Walden (2000) or Section
  7.3 in Gencay, Selcuk and Whitcher (2001).
}
\references{
  Gencay, R., F. Selcuk and B. Whitcher (2001)
  \emph{An Introduction to Wavelets and Other Filtering Methods in
    Finance and Economics},
  Academic Press.
  
  Percival, D. B. and A. T. Walden (2000)
  \emph{Wavelet Methods for Time Series Analysis},
  Cambridge University Press.
}
\seealso{\code{\link{dwt}}, \code{\link{modwt}},
  \code{\link{rotcumvar}}, \code{\link{mult.loc}}.
}
%\examples{}
\author{B. Whitcher}
\keyword{ts}

\eof
\name{tourism}
\alias{tourism}
\title{U.S. Tourism}
\description{
  Quarterly U.S. tourism figures from 1960:1 to 1999:4.
}
\usage{data(tourism)
}
\format{A vector containing 160 observations.
}
\source{Unknown.
}
\references{
  Gencay, R., F. Selcuk and B. Whitcher (2001)
  \emph{An Introduction to Wavelets and Other Filtering Methods in
    Finance and Economics},
  Academic Press.
}
\keyword{datasets}

\eof
\name{unemploy}
\alias{unemploy}
\title{U.S. Unemployment}
\description{
  Monthly U.S. unemployment figures from 1948:1 to 1999:12.
}
\usage{data(unemploy)
}
\format{A vector containing 624 observations.
}
\source{Unknown.
}
\references{
  Gencay, R., F. Selcuk and B. Whitcher (2001)
  \emph{An Introduction to Wavelets and Other Filtering Methods in
    Finance and Economics},
  Academic Press.
}
\keyword{datasets}

\eof
\name{up.sample}
\alias{up.sample}
\title{Upsampling of a vector}
\description{
  Upsamples a given vector.
}
\usage{up.sample(x, f, y = NA)
}
\arguments{
  \item{x}{vector of observations}
  \item{f}{frequency of upsampling; e.g, 2, 4, etc.}
  \item{y}{value to upsample with; e.g., NA, 0, etc.}
}
\value{
  A vector twice its length.
}
%\details{}
\references{
  Any basic signal processing text.
}
%\seealso{}
%\examples{}
\author{B. Whitcher}
\keyword{ts}

\eof
\name{wave.filter}
\alias{wave.filter}
\title{Select a Wavelet Filter}
\description{
  Converts name of wavelet filter to filter coefficients.
}
\usage{wave.filter(name)
}
\arguments{
  \item{name}{Character string of wavelet filter.}
}
\value{
  List containing the following items:
  \item{L}{Length of the wavelet filter.}
  \item{hpf}{High-pass filter coefficients.}
  \item{lpf}{Low-pass filter coefficients.}
}
\details{
  Simple \code{switch} statement selects the appropriate filter.
}
\references{
  Daubechies, I. (1992)
  \emph{Ten Lectures on Wavelets},
  CBMS-NSF Regional Conference Series in Applied Mathematics,
  SIAM: Philadelphia.

  Doroslovacki (1998)
  On the least asymmetric wavelets,
  \emph{IEEE Transactions for Signal Processing}, \bold{46}, No. 4,
  1125-1130.

  Morris and Peravali (1999)
  Minimum-bandwidth discrete-time wavelets,
  \emph{Signal Processing}, \bold{76}, No. 2, 181-193.

  Nielsen, M. (2000)
  On the Construction and Frequency Localization of Orthogonal
  Quadrature Filters,
  \emph{Journal of Approximation Theory}, \bold{108}, No. 1, 36-52.
}
\seealso{
  \code{\link{wavelet.filter}}, \code{\link{squared.gain}}.
}
%\examples{}
\author{B. Whitcher}
\keyword{ts}

\eof
\name{wave.variance}
\alias{wave.variance}
\alias{wave.covariance}
\alias{wave.correlation}
\title{Wavelet Analysis of Univariate/Bivariate Time Series}
\description{
  Produces an estimate of the multiscale variance, covariance or
  correlation along with approximate confidence intervals.
}
\usage{wave.variance(x, type="eta3", p=0.025)
wave.covariance(x, y)
wave.correlation(x, y, N, p=0.975)
}
\arguments{
  \item{x}{first time series}
  \item{y}{second time series}
  \item{type}{character string describing confidence interval
    calculation; valid methods are \code{gaussian}, \code{eta1},
    \code{eta2}, \code{eta3}, \code{nongaussian}}
  \item{p}{(one minus the) two-sided p-value for the confidence interval}
  \item{N}{length of time series}
}
\value{
  Matrix with as many rows as levels in the wavelet transform object.
  The first column provides the point estimate for the wavelet variance,
  covariance, or correlation followed by the lower and upper bounds from
  the confidence interval.
}
\details{
  The time-independent wavelet variance is basically the average of the
  squared wavelet coefficients across each scale.  As shown in Percival
  (1995), the wavelet variance is a scale-by-scale decomposition of the
  variance for a stationary process, and certain non-stationary
  processes.
}
\references{
  Gencay, R., F. Selcuk and B. Whitcher (2001)
  \emph{An Introduction to Wavelets and Other Filtering Methods in
    Finance and Economics},
  Academic Press.

  Percival, D. B. (1995)
  \emph{Biometrika}, \bold{82}, No. 3, 619-631.

  Percival, D. B. and A. T. Walden (2000)
  \emph{Wavelet Methods for Time Series Analysis},
  Cambridge University Press.

  Whitcher, B., P. Guttorp and D. B. Percival (2000)
  Wavelet Analysis of Covariance with Application to Atmospheric Time
  Series, \emph{Journal of Geophysical Research}, \bold{105}, No. D11,
  14,941-14,962.
}
%\seealso{}
\examples{
## Figure 7.3 from Gencay, Selcuk and Whitcher (2001)
data(ar1)
ar1.modwt <- modwt(ar1, "haar", 6)
ar1.modwt.bw <- brick.wall(ar1.modwt, "haar")
ar1.modwt.var2 <- wave.variance(ar1.modwt.bw, type="gaussian")
ar1.modwt.var <- wave.variance(ar1.modwt.bw, type="nongaussian")
par(mfrow=c(1,1), las=1, mar=c(5,4,4,2)+.1)
matplot(2^(0:5), ar1.modwt.var2[-7,], type="b", log="xy",
        xaxt="n", ylim=c(.025, 6), pch="*LU", lty=1, col=c(1,4,4),
        xlab="Wavelet Scale", ylab="")
matlines(2^(0:5), as.matrix(ar1.modwt.var)[-7,2:3], type="b",
         pch="LU", lty=1, col=3)
axis(side=1, at=2^(0:5))
legend(1, 6, c("Wavelet variance", "Gaussian CI", "Non-Gaussian CI"),
       lty=1, col=c(1,4,3), bty="n")

## Figure 7.8 from Gencay, Selcuk and Whitcher (2001)
data(exchange)
returns <- diff(log(as.matrix(exchange)))
returns <- ts(returns, start=1970, freq=12)
wf <- "d4"
J <- 6
demusd.modwt <- modwt(returns[,"DEM.USD"], wf, J)
demusd.modwt.bw <- brick.wall(demusd.modwt, wf)
jpyusd.modwt <- modwt(returns[,"JPY.USD"], wf, J)
jpyusd.modwt.bw <- brick.wall(jpyusd.modwt, wf)
returns.modwt.cov <- wave.covariance(demusd.modwt.bw, jpyusd.modwt.bw)
par(mfrow=c(1,1), las=0, mar=c(5,4,4,2)+.1)
matplot(2^(0:(J-1)), returns.modwt.cov[-(J+1),], type="b", log="x",
        pch="*LU", xaxt="n", lty=1, col=c(1,4,4), xlab="Wavelet Scale", 
        ylab="Wavelet Covariance")
axis(side=1, at=2^(0:7))
abline(h=0)

returns.modwt.cor <- wave.correlation(demusd.modwt.bw, jpyusd.modwt.bw,
                                      N = dim(returns)[1])
par(mfrow=c(1,1), las=0, mar=c(5,4,4,2)+.1)
matplot(2^(0:(J-1)), returns.modwt.cor[-(J+1),], type="b", log="x",
        pch="*LU", xaxt="n", lty=1, col=c(1,4,4), xlab="Wavelet Scale", 
        ylab="Wavelet Correlation")
axis(side=1, at=2^(0:7))
abline(h=0)
}
\author{B. Whitcher}
\keyword{ts}

\eof
\name{wavelet.filter}
\alias{wavelet.filter}
\title{Higher-Order Wavelet Filters}
\description{
  Create a wavelet filter at arbitrary scale.
}
\usage{wavelet.filter(wf.name, filter.seq = "L", n = 512) 
}
\arguments{
  \item{wf.name}{Character string of wavelet filter.}
  \item{filter.seq}{Character string of filter sequence.  \code{H} means
    high-pass filtering and \code{L} means low-pass filtering.  Sequence
    is read from right to left.}
  \item{n}{Length of zero-padded filter.  Frequency resolution will be
    \code{n}/2+1.}
}
\value{
  Vector of wavelet coefficients.
}
\details{
  Uses \code{cascade} subroutine to compute higher-order wavelet
  coefficient vector from a given filtering sequence.
}
\references{
  Bruce, A. and H.-Y. Gao (1996).
  \emph{Applied Wavelet Analysis with S-PLUS},
  Springer: New York.
  
  Doroslovacki, M. L. (1998)
  On the least asymmetric wavelets,
  \emph{IEEE Transactions on Signal Processing}, \bold{46}, No. 4,
  1125-1130.
  
  Daubechies, I. (1992)
  \emph{Ten Lectures on Wavelets},
  CBMS-NSF Regional Conference Series in Applied Mathematics,
  SIAM: Philadelphia.

  Morris and Peravali (1999)
  Minimum-bandwidth discrete-time wavelets,
  \emph{Signal Processing}, \bold{76}, No. 2, 181-193.

  Nielsen, M. (2001)
  On the Construction and Frequency Localization of Finite Orthogonal
  Quadrature Filters,
  \emph{Journal of Approximation Theory}, \bold{108}, No. 1, 36-52.
}
\seealso{
  \code{\link{squared.gain}}, \code{\link{wave.filter}}.
}
\examples{
## Figure 4.14 in Gencay, Selcuk and Whitcher (2001)
par(mfrow=c(3,1), mar=c(5-2,4,4-1,2))
f.seq <- "HLLLLL"
plot(c(rep(0,33), wavelet.filter("mb4", f.seq), rep(0,33)), type="l",
     xlab="", ylab="", main="D(4) in black, MB(4) in red")
lines(c(rep(0,33), wavelet.filter("d4", f.seq), rep(0,33)), col=2)
plot(c(rep(0,35), -wavelet.filter("mb8", f.seq), rep(0,35)), type="l",
     xlab="", ylab="", main="D(8) in black, -MB(8) in red")
lines(c(rep(0,35), wavelet.filter("d8", f.seq), rep(0,35)), col=2)
plot(c(rep(0,39), wavelet.filter("mb16", f.seq), rep(0,39)), type="l",
     xlab="", ylab="", main="D(16) in black, MB(16) in red")
lines(c(rep(0,39), wavelet.filter("d16", f.seq), rep(0,39)), col=2)
}
\author{B. Whitcher}
\keyword{ts}

\eof
\name{wpt.test}
\alias{cpgram.test}
\alias{css.test}
\alias{entropy.test}
\alias{portmanteau.test}
\title{Testing the Wavelet Packet Tree for White Noise}
\description{
  A wavelet packet tree, from the discrete wavelet packet transform
  (DWPT), is tested node-by-node for white noise.  This is the first
  step in selecting an orthonormal basis for the DWPT.
}
\usage{cpgram.test(y, p = 0.05, taper = 0.1)
css.test(y)
entropy.test(y)
portmanteau.test(y, p = 0.05, type = "Box-Pierce")
}
\arguments{
  \item{y}{wavelet packet tree (from the DWPT)}
  \item{p}{significance level}
  \item{taper}{weight of cosine bell taper (\code{cpgram.test} only)}
  \item{type}{\code{"Box-Pierce"} and \code{other} recognized
    (\code{portmanteau.test} only)}
}
\value{
  Boolean vector of the same length as the number of nodes in the
  wavelet packet tree.
}
\details{
  Top-down recursive testing of the wavelet packet tree is 
}
\references{
  Brockwell and Davis (1991)
  \emph{Time Series: Theory and Methods}, (2nd. edition),
  Springer-Verlag.

  Brown, Durbin and Evans (1975)
  Techniques for testing the constancy of regression relationships over
  time,
  \emph{Journal of the Royal Statistical Society B}, \bold{37}, 149-163.

  Percival, D. B., and A. T. Walden (1993)
  \emph{Spectral Analysis for Physical Applications: Multitaper and
    Conventional Univariate Techniques},
  Cambridge University Press.
}
\seealso{
  \code{\link{ortho.basis}}.
}
\examples{
data(mexm)
J <- 6
wf <- "la8"
mexm.dwpt <- dwpt(mexm[-(1:4)], wf, J)
## Not implemented yet
## plot.dwpt(x.dwpt, J)
mexm.dwpt.bw <- dwpt.brick.wall(mexm.dwpt, wf, 6, method="dwpt")
mexm.tree <- ortho.basis(portmanteau.test(mexm.dwpt.bw, p=0.025))
## Not implemented yet
## plot.basis(mexm.tree)
}
\author{B. Whitcher}
\keyword{ts}

\eof
\name{xbox}
\alias{xbox}
\title{Image with Box and X}
\description{
  \deqn{xbox(i,j) = I_{[i=n/4,\;3n/4,\;j;~ n/4 \leq j \leq 3n/4]} +
    I_{[n/4 \leq i \leq 3n/4;~ j=n/4,\;3n/4,\;i]}}{%
    xbox(i,j) = I_[i = n/4, 3n/4, j; n/4 \leq j \leq 3n/4] +
    I_[n/4 \leq i \leq 3n/4; j = n/4, 3n/4, i]}
}
\usage{data(xbox)
}
\format{A 128 \eqn{\times}{x} 128 matrix.
}
\source{S+WAVELETS.
}
\references{
  Bruce, A., and H.-Y. Gao (1996)
  \emph{Applied Wavelet Analysis with S-PLUS}, Springer: New York.
}
\keyword{datasets}

\eof
